(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    113285,       2957]*)
(*NotebookOutlinePosition[    152120,       4265]*)
(*  CellTagsIndexPosition[    152076,       4261]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Notebook for \"",
  "Asymptotic Methods for Asset Market Equilibrium Analysis\" by Judd and \
Guu"
}], "Title"],

Cell[TextData[{
  "The following ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " program computes asset market equilibrium for two investors, one safe \
asset, and one or two risky assets."
}], "Text"],

Cell["The first command turns off annoying spelling queries.", "Text"],

Cell[BoxData[
    \(Off[General::spell1]\)], "Input"],

Cell[CellGroupData[{

Cell["The initial setup", "Section"],

Cell[CellGroupData[{

Cell["Economic Model", "Subsection"],

Cell[TextData[{
  "\tDefine the two risky assets' returns, ",
  Cell[BoxData[
      \(TraditionalForm\`Z\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`Y\)]],
  ", in terms of zero-mean random variables z and y. \[Epsilon] is the \
scaling parameter, equal to the standard deviation in the \[Epsilon]-economy. \
",
  Cell[BoxData[
      \(TraditionalForm\`Z\)]],
  " is an asset with mean return ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " and variance ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\^2\)]],
  ", and is in positive net supply. It represents equity. To keep the \
formulas simple, we assume that the return on bonds, ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  ", is 1. This is equivalent to assuming that the bond in the second period \
is the numeraire.\n\tThese facts imply that ",
  Cell[BoxData[
      \(TraditionalForm\`Z\)]],
  " can be decomposed in the following manner:"
}], "Text"],

Cell[BoxData[
    \(\(Z = 1 + \[Epsilon]\ z;\)\)], "Input",
  FontFamily->"Courier New"],

Cell[TextData[{
  "Y is the derivative asset and has zero net supply. It has mean return \
\[Epsilon] ",
  Cell[BoxData[
      \(\[Mu]Y\)],
    FontFamily->"Courier New"],
  ", is partially correlated with ",
  Cell[BoxData[
      \(TraditionalForm\`Z\)]],
  " through the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\ \[Alpha]\ z\)]],
  " term, and has an orthogonal component ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\ y\)]],
  ". These facts imply that ",
  Cell[BoxData[
      \(TraditionalForm\`Y\)]],
  " can be represented as"
}], "Text"],

Cell[BoxData[
    \(\(Y = \[Epsilon]\ \[Mu]Y\ \  + \ \[Epsilon]\ \[Alpha]\ z\  + \
\[Epsilon]\ \ y;\)\)], "Input"],

Cell[TextData[{
  "\tThe price of ",
  Cell[BoxData[
      \(TraditionalForm\`Z\ \((Y)\)\)]],
  " is ",
  Cell[BoxData[
      \(TraditionalForm\`p\ \((q)\)\)]],
  ". We parametrize them in terms of the scaling parameter ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  ", the mean of ",
  Cell[BoxData[
      \(TraditionalForm\`Y\)]],
  ",  ",
  Cell[BoxData[Cell[TextData[{
        "\[Mu]",
        Cell[BoxData[
            \(TraditionalForm\`Y\)]]
      }]]],
    FontFamily->"Courier New"],
  ", and the premia of ",
  Cell[BoxData[
      \(TraditionalForm\`Z\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`Y\)]],
  ", denoted ",
  Cell[BoxData[
      FormBox[Cell["\[CapitalPi]"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPsi]\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(p\  = \ 1\  - \[Epsilon]\^2\ \ \[CapitalPi]\ ; \ 
    q\  = \[Epsilon]\ \ \[Mu]Y\  - \ \[Epsilon]\^2\ \[CapitalPsi]\ ;\)], \
"Input",
  FontFamily->"Courier New"],

Cell[TextData[{
  "Note: The notation in the notebook corresponds to the notation in the \
paper except for a minor change. In ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", the letter \[Pi] is reserved for 3.14159... and so we could not use it \
as the risk premium for ",
  Cell[BoxData[
      \(TraditionalForm\`Z\)]],
  ". Therefore, we use \[CapitalPi] instead. To maintain the symmetry we also \
let \[CapitalPsi] denote the premium for ",
  Cell[BoxData[
      \(TraditionalForm\`Y\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`W\_i\)]],
  " is final wealth of type",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(i\)\)\)]],
  " investor. \[Theta] is type 1 demand for equity. ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]e\_i\)]],
  " is type ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " endowment of equity and ",
  Cell[BoxData[
      \(TraditionalForm\`Be\_i\)]],
  " is type ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " endowment of bonds.  \[Phi] is type 1's demand for Y; - \[Phi] is type 2 \
demand. In equilibrium, type 2 investors will hold ",
  Cell[BoxData[Cell[TextData[{
        Cell[BoxData[
            \(TraditionalForm\`\[Theta]e\_1\)]],
        "+",
        Cell[BoxData[
            \(TraditionalForm\`\[Theta]e\_2\)]],
        "-\[Theta]"
      }]]]],
  " shares of stock. ( ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " prevented us from using ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\_i\%e\)]],
  " (",
  Cell[BoxData[
      \(TraditionalForm\`B\_i\%e\)]],
  ") to denote type ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " endowment of the risky asset (bond).)"
}], "Text"],

Cell[BoxData[
    \(\[Theta]e\_1 = \[Theta]e\_1; \[Theta]e\_2 = \[Theta]e\_2;\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    RowBox[{\(W\_1\), "=", 
      RowBox[{
        RowBox[{"(", 
          RowBox[{
            FormBox[\(Be\_1\),
              "TraditionalForm"], "+", " ", \(p\ \[Theta]e\_1\), 
            "-", \(p\ \[Theta]\), "-", " ", \(q\ \[Phi]\)}], ")"}], 
        "+", \(\[Theta]*Z\), "+", \(\[Phi]\ Y\)}]}], "\n", 
    RowBox[{
      RowBox[{\(W\_2\), "=", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              FormBox[\(Be\_2\),
                "TraditionalForm"], "+", " ", \(p\ \[Theta]e\_2\), 
              "-", \(p\ \((\[Theta]e\_1 + \[Theta]e\_2 - \[Theta])\)\), "-", 
              " ", \(q\ \((\(-\[Phi]\))\)\)}], ")"}], 
          "+", \(\((\[Theta]e\_1 + \[Theta]e\_2 - \[Theta])\)*Z\), 
          "+", \(\((\(-\[Phi]\))\) Y\)}]}], 
      ";"}], "\n", \(W\_1 = Expand[W\_1];\), "\n", \(W\_2 = 
        Expand[W\_2];\)}], "Input"],

Cell[BoxData[
    \(\((1 + 
            z\ \[Epsilon])\)\ \[Theta] - \[Theta]\ \((1 - \[Epsilon]\^2\ \
\[CapitalPi])\) + \((y\ \[Epsilon] + 
            z\ \[Alpha]\ \[Epsilon] + \[Epsilon]\ \[Mu]Y)\)\ \[Phi] - \[Phi]\ \
\((\[Epsilon]\ \[Mu]Y - \[Epsilon]\^2\ \[CapitalPsi])\) + 
      Be\_1 + \((1 - \[Epsilon]\^2\ \[CapitalPi])\)\ \[Theta]e\_1\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tWe compute the four first-order conditions for the two investors and the \
two risky assets. The bond demand is determined by substracting risky asset \
demand from initial wealth. We divide each first-order condition by \
\[Epsilon] to eliminate one degree of degeneracy. FOCij is the first-order \
condition of type ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " investor with respect to risky asset",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(j\)\)\)]],
  ", where",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(j = 1\)\)\)]],
  " is equity and ",
  Cell[BoxData[
      \(TraditionalForm\`j = 2\)]],
  " refers to the derivative."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(FOC11 = \((1/\[Epsilon])\) D[u\_1[W\_1], \[Theta]] // 
        Simplify\), "\n", 
    \(FOC12 = \((1/\[Epsilon])\) D[u\_1[W\_1], \[Phi]] // Simplify\), "\n", 
    \(FOC21 = \((1/\[Epsilon])\) D[u\_2[W\_2], \[Theta]] // 
        Simplify\), "\n", 
    \(FOC22 = \((1/\[Epsilon])\) D[u\_2[W\_2], \[Phi]] // 
        Simplify\)}], "Input"],

Cell[BoxData[
    RowBox[{\((z + \[Epsilon]\ \[CapitalPi])\), " ", 
      RowBox[{
        SubsuperscriptBox["u", "1", "\[Prime]",
          MultilineFunction->None], 
        "[", \(\[Epsilon]\ \((z\ \[Theta] + \[Epsilon]\ \[Theta]\ \
\[CapitalPi] + y\ \[Phi] + 
                z\ \[Alpha]\ \[Phi] + \[Epsilon]\ \[Phi]\ \[CapitalPsi])\) + 
          Be\_1 + \((1 - \[Epsilon]\^2\ \[CapitalPi])\)\ \[Theta]e\_1\), 
        "]"}]}]], "Output"],

Cell[BoxData[
    RowBox[{\((y + z\ \[Alpha] + \[Epsilon]\ \[CapitalPsi])\), " ", 
      RowBox[{
        SubsuperscriptBox["u", "1", "\[Prime]",
          MultilineFunction->None], 
        "[", \(\[Epsilon]\ \((z\ \[Theta] + \[Epsilon]\ \[Theta]\ \
\[CapitalPi] + y\ \[Phi] + 
                z\ \[Alpha]\ \[Phi] + \[Epsilon]\ \[Phi]\ \[CapitalPsi])\) + 
          Be\_1 + \((1 - \[Epsilon]\^2\ \[CapitalPi])\)\ \[Theta]e\_1\), 
        "]"}]}]], "Output"],

Cell[BoxData[
    RowBox[{\(-\((z + \[Epsilon]\ \[CapitalPi])\)\), " ", 
      RowBox[{
        SubsuperscriptBox["u", "2", "\[Prime]",
          MultilineFunction->None], 
        "[", \(\(-z\)\ \[Epsilon]\ \[Theta] - \[Epsilon]\^2\ \[Theta]\ \
\[CapitalPi] - y\ \[Epsilon]\ \[Phi] - 
          z\ \[Alpha]\ \[Epsilon]\ \[Phi] - \[Epsilon]\^2\ \[Phi]\ \
\[CapitalPsi] + 
          Be\_2 + \[Epsilon]\ \((z + \[Epsilon]\ \[CapitalPi])\)\ \
\[Theta]e\_1 + \[Theta]e\_2 + z\ \[Epsilon]\ \[Theta]e\_2\), 
        "]"}]}]], "Output"],

Cell[BoxData[
    RowBox[{\(-\((y + z\ \[Alpha] + \[Epsilon]\ \[CapitalPsi])\)\), " ", 
      RowBox[{
        SubsuperscriptBox["u", "2", "\[Prime]",
          MultilineFunction->None], 
        "[", \(\(-z\)\ \[Epsilon]\ \[Theta] - \[Epsilon]\^2\ \[Theta]\ \
\[CapitalPi] - y\ \[Epsilon]\ \[Phi] - 
          z\ \[Alpha]\ \[Epsilon]\ \[Phi] - \[Epsilon]\^2\ \[Phi]\ \
\[CapitalPsi] + 
          Be\_2 + \[Epsilon]\ \((z + \[Epsilon]\ \[CapitalPi])\)\ \
\[Theta]e\_1 + \[Theta]e\_2 + z\ \[Epsilon]\ \[Theta]e\_2\), 
        "]"}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tEven though we have divided by \[Epsilon], these first-order conditions \
describe the situation at \[Epsilon]=0.\nThese four first-order conditions \
define equilibrium. Define ",
  Cell[BoxData[
      \(TraditionalForm\`G\)]],
  " to be the vector of first-order conditions."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Moment substitutions and other substitutions", "Subsection"],

Cell[TextData[{
  "\tWe next define lists of substitutions that allow us to compute the \
moments of",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(z\)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  ". The doubly subscripted term ",
  Cell[BoxData[
      \(\[Mu]\_\(m, n\)\)]],
  " denotes the expectation of ",
  Cell[BoxData[
      \(\(z\^m\) y\^n\)]],
  ". We often need to compute expectations of our Taylor series expansions. \
We could invoke ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s Integrate command, but we can do better by searching for specific terms \
in our polynomials and replacing them with their integrals. For example, \
whenever we see an isolated ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " in an expression we know that its integral just replaces the ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " term by the mean of ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  ", which is denoted as ",
  Cell[BoxData[
      \(\[Mu]\_\(1, 0\)\)]],
  ". This works better than integration in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " since we know that our function is a polynomial whereas ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " needs to spend time to ascertain that fact. The following replacement \
rules implement this approach to integration."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(ownmoments\  = \ {z \[Rule] \[Mu]\_\(1, 0\), 
        z\^m_ \[Rule] \ \[Mu]\_\(m, 0\), y \[Rule] \[Mu]\_\(0, 1\), 
        y\^m_ \[Rule] \ \[Mu]\_\(0, m\)}\), "\n", 
    \(crossmoments\  = \ {\(z\^m_\) y\^n_ \[Rule] \ \[Mu]\_\(m, n\), 
        z\ y\^n_ \[Rule] \ \[Mu]\_\(1, n\), \(z\^m_\) 
            y \[Rule] \ \[Mu]\_\(m, 1\)}\)}], "Input"],

Cell[BoxData[
    \({z \[Rule] \[Mu]\_\(1, 0\), z\^m_ \[Rule] \[Mu]\_\(m, 0\), 
      y \[Rule] \[Mu]\_\(0, 1\), y\^m_ \[Rule] \[Mu]\_\(0, m\)}\)], "Output"],

Cell[BoxData[
    \({y\^n_\ z\^m_ \[Rule] \[Mu]\_\(m, n\), 
      y\^n_\ z \[Rule] \[Mu]\_\(1, n\), 
      y\ z\^m_ \[Rule] \[Mu]\_\(m, 1\)}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tOur definition of ",
  Cell[BoxData[
      \(TraditionalForm\`Y\)]],
  " decomposed it into its mean, it covariance with ",
  Cell[BoxData[
      \(TraditionalForm\`Z\)]],
  ", and the orthogonal residual. Without loss of generality, we set the mean \
of ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " to zero."
}], "Text"],

Cell[BoxData[
    \(\(zeromean\  = \ {\[Mu]\_\(0, 1\) \[Rule] 0, \[Mu]\_\(1, 0\) \[Rule] 
            0};\)\)], "Input"],

Cell[TextData[{
  "\tWe make ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " orthogonal and set the variance of ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " equal to 1."
}], "Text"],

Cell[BoxData[
    \(\(orthogonal\  = \ {\[Mu]\_\(1, 1\) \[Rule] 0, \[Mu]\_\(2, 0\) \[Rule] 
            1};\)\)], "Input"],

Cell["\tWe now gather all the substitions into one list.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(moments\  = \ 
      Join[ownmoments, crossmoments, zeromean, \ orthogonal]\)], "Input"],

Cell[BoxData[
    \({z \[Rule] \[Mu]\_\(1, 0\), z\^m_ \[Rule] \[Mu]\_\(m, 0\), 
      y \[Rule] \[Mu]\_\(0, 1\), y\^m_ \[Rule] \[Mu]\_\(0, m\), 
      y\^n_\ z\^m_ \[Rule] \[Mu]\_\(m, n\), y\^n_\ z \[Rule] \[Mu]\_\(1, n\), 
      y\ z\^m_ \[Rule] \[Mu]\_\(m, 1\), \[Mu]\_\(0, 1\) \[Rule] 
        0, \[Mu]\_\(1, 0\) \[Rule] 0, \[Mu]\_\(1, 1\) \[Rule] 
        0, \[Mu]\_\(2, 0\) \[Rule] 1}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tThe following substitutions denote the case where there is no derivative \
security. They say that all cross-moments between ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " are zero. Note that ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " must be nonzero since we set its variance to 1. However, if all of its \
moments are uncorrelated with all moments of the endowment then it is a pure \
gamble and will not be traded in equilibrium."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NoDeriv = 
      Table[\[Mu]\_\(m, n\) \[Rule] 0, {m, 1, 6}, {n, 1, 6}] // 
        Flatten\)], "Input"],

Cell[BoxData[
    \({\[Mu]\_\(1, 1\) \[Rule] 0, \[Mu]\_\(1, 2\) \[Rule] 
        0, \[Mu]\_\(1, 3\) \[Rule] 0, \[Mu]\_\(1, 4\) \[Rule] 
        0, \[Mu]\_\(1, 5\) \[Rule] 0, \[Mu]\_\(1, 6\) \[Rule] 
        0, \[Mu]\_\(2, 1\) \[Rule] 0, \[Mu]\_\(2, 2\) \[Rule] 
        0, \[Mu]\_\(2, 3\) \[Rule] 0, \[Mu]\_\(2, 4\) \[Rule] 
        0, \[Mu]\_\(2, 5\) \[Rule] 0, \[Mu]\_\(2, 6\) \[Rule] 
        0, \[Mu]\_\(3, 1\) \[Rule] 0, \[Mu]\_\(3, 2\) \[Rule] 
        0, \[Mu]\_\(3, 3\) \[Rule] 0, \[Mu]\_\(3, 4\) \[Rule] 
        0, \[Mu]\_\(3, 5\) \[Rule] 0, \[Mu]\_\(3, 6\) \[Rule] 
        0, \[Mu]\_\(4, 1\) \[Rule] 0, \[Mu]\_\(4, 2\) \[Rule] 
        0, \[Mu]\_\(4, 3\) \[Rule] 0, \[Mu]\_\(4, 4\) \[Rule] 
        0, \[Mu]\_\(4, 5\) \[Rule] 0, \[Mu]\_\(4, 6\) \[Rule] 
        0, \[Mu]\_\(5, 1\) \[Rule] 0, \[Mu]\_\(5, 2\) \[Rule] 
        0, \[Mu]\_\(5, 3\) \[Rule] 0, \[Mu]\_\(5, 4\) \[Rule] 
        0, \[Mu]\_\(5, 5\) \[Rule] 0, \[Mu]\_\(5, 6\) \[Rule] 
        0, \[Mu]\_\(6, 1\) \[Rule] 0, \[Mu]\_\(6, 2\) \[Rule] 
        0, \[Mu]\_\(6, 3\) \[Rule] 0, \[Mu]\_\(6, 4\) \[Rule] 
        0, \[Mu]\_\(6, 5\) \[Rule] 0, \[Mu]\_\(6, 6\) \[Rule] 0}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tWe define a convenient list of simplifying substitutions which ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " did not automatically execute."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"sub1", "=", 
      RowBox[{"{", 
        RowBox[{
          RowBox[{
            RowBox[{\(1\/2\), 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"2", " ", 
                    FormBox[\(Be\_1\),
                      "TraditionalForm"]}], "+", \(2\ \[Theta]e\_1\)}], 
                ")"}]}], "\[Rule]", " ", 
            RowBox[{"(", 
              RowBox[{
                FormBox[\(Be\_1\),
                  "TraditionalForm"], "+", \(\[Theta]e\_1\)}], ")"}]}], ",", 
          RowBox[{
            RowBox[{\(1\/2\), 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"2", " ", 
                    FormBox[\(Be\_2\),
                      "TraditionalForm"]}], "+", \(2\ \[Theta]e\_2\)}], 
                ")"}]}], "\[Rule]", 
            RowBox[{"(", 
              RowBox[{
                FormBox[\(Be\_2\),
                  "TraditionalForm"], "+", \(\[Theta]e\_2\)}], ")"}]}]}], 
        "}"}]}]], "Input"],

Cell[BoxData[
    \({1\/2\ \((2\ Be\_1 + 2\ \[Theta]e\_1)\) \[Rule] Be\_1 + \[Theta]e\_1, 
      1\/2\ \((2\ Be\_2 + 2\ \[Theta]e\_2)\) \[Rule] 
        Be\_2 + \[Theta]e\_2}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solvability Condition in Theorem 4", "Section"],

Cell[TextData[{
  "\tWe check for the nonsingularity of the solvability matrix, ",
  Cell[BoxData[
      \(TraditionalForm\`G\_\(\[Epsilon], \[CapitalLambda]\)\)]],
  " where \[CapitalLambda]=(\[Theta],",
  "\[Phi]",
  ",\[CapitalPi],\[CapitalPsi]). First define the solvability matrix:"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        FormBox[\(G\_\(\[Epsilon], \[CapitalLambda]\)\),
          "TraditionalForm"], "=", 
        "\[IndentingNewLine]", \({{D[FOC11, {\[Epsilon], 1}, \[Theta]], 
            D[FOC11, {\[Epsilon], 1}, \[Phi]], 
            D[FOC11, {\[Epsilon], 1}, \[CapitalPsi]], 
            D[FOC11, {\[Epsilon], 1}, \[CapitalPi]]}, \[IndentingNewLine]{D[
              FOC12, {\[Epsilon], 1}, \[Theta]], 
            D[FOC12, {\[Epsilon], 1}, \[Phi]], 
            D[FOC12, {\[Epsilon], 1}, \[CapitalPsi]], 
            D[FOC12, {\[Epsilon], 1}, \[CapitalPi]]}, \[IndentingNewLine]{D[
              FOC21, {\[Epsilon], 1}, \[Theta]], 
            D[FOC21, {\[Epsilon], 1}, \[Phi]], 
            D[FOC21, {\[Epsilon], 1}, \[CapitalPsi]], 
            D[FOC21, {\[Epsilon], 1}, \[CapitalPi]]}, \[IndentingNewLine]{D[
              FOC22, {\[Epsilon], 1}, \[Theta]], 
            D[FOC22, {\[Epsilon], 1}, \[Phi]], 
            D[FOC22, {\[Epsilon], 1}, \[CapitalPsi]], 
            D[FOC22, {\[Epsilon], 1}, \[CapitalPi]]}}\)}], ";"}]], "Input"],

Cell[TextData[{
  "Evaluate ",
  Cell[BoxData[
      \(TraditionalForm\`G\_\(\[Epsilon], \[CapitalLambda]\)\)]],
  " at \[Epsilon]=0 and display it in matrix form:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(G\_\(\[Epsilon], \[CapitalLambda]\) = 
        G\_\(\[Epsilon], \[CapitalLambda]\) /. {\[Epsilon] -> 0};\)\), "\n", 
    \(G\_\(\[Epsilon], \[CapitalLambda]\) // MatrixForm\)}], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              RowBox[{\(z\^2\), " ", 
                RowBox[{
                  SubsuperscriptBox["u", "1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", \(Be\_1 + \[Theta]e\_1\), 
                  "]"}]}], 
              RowBox[{"z", " ", \((y + z\ \[Alpha])\), " ", 
                RowBox[{
                  SubsuperscriptBox["u", "1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", \(Be\_1 + \[Theta]e\_1\), 
                  "]"}]}], "0", 
              RowBox[{
                SubsuperscriptBox["u", "1", "\[Prime]",
                  MultilineFunction->None], "[", \(Be\_1 + \[Theta]e\_1\), 
                "]"}]},
            {
              RowBox[{"z", " ", \((y + z\ \[Alpha])\), " ", 
                RowBox[{
                  SubsuperscriptBox["u", "1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", \(Be\_1 + \[Theta]e\_1\), 
                  "]"}]}], 
              RowBox[{\(\((y + z\ \[Alpha])\)\^2\), " ", 
                RowBox[{
                  SubsuperscriptBox["u", "1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", \(Be\_1 + \[Theta]e\_1\), 
                  "]"}]}], 
              RowBox[{
                SubsuperscriptBox["u", "1", "\[Prime]",
                  MultilineFunction->None], "[", \(Be\_1 + \[Theta]e\_1\), 
                "]"}], "0"},
            {
              RowBox[{\(z\^2\), " ", 
                RowBox[{
                  SubsuperscriptBox["u", "2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", \(Be\_2 + \[Theta]e\_2\), 
                  "]"}]}], 
              RowBox[{\(-z\), " ", \((\(-y\) - z\ \[Alpha])\), " ", 
                RowBox[{
                  SubsuperscriptBox["u", "2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", \(Be\_2 + \[Theta]e\_2\), 
                  "]"}]}], "0", 
              RowBox[{"-", 
                RowBox[{
                  SubsuperscriptBox["u", "2", "\[Prime]",
                    MultilineFunction->None], "[", \(Be\_2 + \[Theta]e\_2\), 
                  "]"}]}]},
            {
              RowBox[{"z", " ", \((y + z\ \[Alpha])\), " ", 
                RowBox[{
                  SubsuperscriptBox["u", "2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", \(Be\_2 + \[Theta]e\_2\), 
                  "]"}]}], 
              
              RowBox[{\(-\((\(-y\) - z\ \[Alpha])\)\), 
                " ", \((y + z\ \[Alpha])\), " ", 
                RowBox[{
                  SubsuperscriptBox["u", "2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", \(Be\_2 + \[Theta]e\_2\), 
                  "]"}]}], 
              RowBox[{"-", 
                RowBox[{
                  SubsuperscriptBox["u", "2", "\[Prime]",
                    MultilineFunction->None], "[", \(Be\_2 + \[Theta]e\_2\), 
                  "]"}]}], "0"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Integrate the elements of ",
  Cell[BoxData[
      \(TraditionalForm\`G\_\(\[Epsilon], \[CapitalLambda]\)\)]],
  " by replacing powers of ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " with their moments."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(ExpG\  = \ 
        Expand[G\_\(\[Epsilon], \[CapitalLambda]\)] //. 
          moments;\)\), "\[IndentingNewLine]", 
    \(ExpG // MatrixForm\)}], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              RowBox[{
                SubsuperscriptBox["u", "1", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", \(Be\_1 + \[Theta]e\_1\), 
                "]"}], 
              RowBox[{"\[Alpha]", " ", 
                RowBox[{
                  SubsuperscriptBox["u", "1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", \(Be\_1 + \[Theta]e\_1\), 
                  "]"}]}], "0", 
              RowBox[{
                SubsuperscriptBox["u", "1", "\[Prime]",
                  MultilineFunction->None], "[", \(Be\_1 + \[Theta]e\_1\), 
                "]"}]},
            {
              RowBox[{"\[Alpha]", " ", 
                RowBox[{
                  SubsuperscriptBox["u", "1", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", \(Be\_1 + \[Theta]e\_1\), 
                  "]"}]}], 
              RowBox[{
                RowBox[{\(\[Alpha]\^2\), " ", 
                  RowBox[{
                    SubsuperscriptBox["u", "1", "\[Prime]\[Prime]",
                      MultilineFunction->None], "[", \(Be\_1 + \[Theta]e\_1\),
                     "]"}]}], "+", 
                RowBox[{\(\[Mu]\_\(0, 2\)\), " ", 
                  RowBox[{
                    SubsuperscriptBox["u", "1", "\[Prime]\[Prime]",
                      MultilineFunction->None], "[", \(Be\_1 + \[Theta]e\_1\),
                     "]"}]}]}], 
              RowBox[{
                SubsuperscriptBox["u", "1", "\[Prime]",
                  MultilineFunction->None], "[", \(Be\_1 + \[Theta]e\_1\), 
                "]"}], "0"},
            {
              RowBox[{
                SubsuperscriptBox["u", "2", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", \(Be\_2 + \[Theta]e\_2\), 
                "]"}], 
              RowBox[{"\[Alpha]", " ", 
                RowBox[{
                  SubsuperscriptBox["u", "2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", \(Be\_2 + \[Theta]e\_2\), 
                  "]"}]}], "0", 
              RowBox[{"-", 
                RowBox[{
                  SubsuperscriptBox["u", "2", "\[Prime]",
                    MultilineFunction->None], "[", \(Be\_2 + \[Theta]e\_2\), 
                  "]"}]}]},
            {
              RowBox[{"\[Alpha]", " ", 
                RowBox[{
                  SubsuperscriptBox["u", "2", "\[Prime]\[Prime]",
                    MultilineFunction->None], "[", \(Be\_2 + \[Theta]e\_2\), 
                  "]"}]}], 
              RowBox[{
                RowBox[{\(\[Alpha]\^2\), " ", 
                  RowBox[{
                    SubsuperscriptBox["u", "2", "\[Prime]\[Prime]",
                      MultilineFunction->None], "[", \(Be\_2 + \[Theta]e\_2\),
                     "]"}]}], "+", 
                RowBox[{\(\[Mu]\_\(0, 2\)\), " ", 
                  RowBox[{
                    SubsuperscriptBox["u", "2", "\[Prime]\[Prime]",
                      MultilineFunction->None], "[", \(Be\_2 + \[Theta]e\_2\),
                     "]"}]}]}], 
              RowBox[{"-", 
                RowBox[{
                  SubsuperscriptBox["u", "2", "\[Prime]",
                    MultilineFunction->None], "[", \(Be\_2 + \[Theta]e\_2\), 
                  "]"}]}], "0"}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Compute the determinant of ",
  Cell[BoxData[
      \(E {G\_\(\[Epsilon], \[CapitalLambda]\)}\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((Det[ExpG] // Simplify)\) //. moments\)], "Input"],

Cell[BoxData[
    RowBox[{\(-\[Mu]\_\(0, 2\)\), " ", 
      SuperscriptBox[
        RowBox[{"(", 
          RowBox[{
            RowBox[{
              RowBox[{
                SubsuperscriptBox["u", "2", "\[Prime]",
                  MultilineFunction->None], "[", \(Be\_2 + \[Theta]e\_2\), 
                "]"}], " ", 
              RowBox[{
                SubsuperscriptBox["u", "1", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", \(Be\_1 + \[Theta]e\_1\), 
                "]"}]}], "+", 
            RowBox[{
              RowBox[{
                SubsuperscriptBox["u", "1", "\[Prime]",
                  MultilineFunction->None], "[", \(Be\_1 + \[Theta]e\_1\), 
                "]"}], " ", 
              RowBox[{
                SubsuperscriptBox["u", "2", "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", \(Be\_2 + \[Theta]e\_2\), 
                "]"}]}]}], ")"}], "2"]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "As long as ",
  Cell[BoxData[
      \(\[Mu]\_\(0, 2\)\)]],
  " is not zero, this determinant is strictly positive and ",
  Cell[BoxData[
      \(G\_\(\[Epsilon], \[CapitalLambda]\)\)]],
  " is nonsingular"
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Bifurcation equations: series construction", "Section"],

Cell["\<\
\tWe construct substitutions that will define the equilibrium mappings from \
the scaling parameter \[Epsilon] to the equilibrium values of \
(\[Theta],\[Phi],\[CapitalPi],\[CapitalPsi]).\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PortfolioSubs\  = \ {\[Theta] \[Rule] \[Theta][\[Epsilon]], \[Phi] \
\[Rule] \[Phi][\[Epsilon]]}\)], "Input"],

Cell[BoxData[
    \({\[Theta] \[Rule] \[Theta][\[Epsilon]], \[Phi] \[Rule] \
\[Phi][\[Epsilon]]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(PremiaSubs\  = \ {\[CapitalPi] \[Rule] \[CapitalPi][\[Epsilon]], \
\[CapitalPsi] \[Rule] \[CapitalPsi][\[Epsilon]]}\)], "Input"],

Cell[BoxData[
    \({\[CapitalPi] \[Rule] \[CapitalPi][\[Epsilon]], \[CapitalPsi] \[Rule] \
\[CapitalPsi][\[Epsilon]]}\)], "Output"]
}, Open  ]],

Cell["\<\
\tTo construct the equilibrium equations we take the first-order conditions \
and replace the the portfolio variables, \[Theta] and \[Phi], and the risk \
premium variables, \[CapitalPi] and \[CapitalPsi],  with their equilibrium \
maps.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(EQM11\  = \ \(FOC11 /. PortfolioSubs\) /. PremiaSubs\), "\n", 
    \(EQM21 = \ \(FOC21 /. PortfolioSubs\) /. PremiaSubs\), "\n", 
    \(EQM12\  = \ \(FOC12 /. PortfolioSubs\) /. PremiaSubs\), "\n", 
    \(EQM22 = \ \(FOC22 /. PortfolioSubs\) /. PremiaSubs\)}], "Input"],

Cell[BoxData[
    RowBox[{\((z + \[Epsilon]\ \[CapitalPi][\[Epsilon]])\), " ", 
      RowBox[{
        SubsuperscriptBox["u", "1", "\[Prime]",
          MultilineFunction->None], 
        "[", \(Be\_1 + \[Theta]e\_1\ \((1 - \[Epsilon]\^2\ \[CapitalPi][\
\[Epsilon]])\) + \[Epsilon]\ \((z\ \[Theta][\[Epsilon]] + \[Epsilon]\ \
\[Theta][\[Epsilon]]\ \[CapitalPi][\[Epsilon]] + y\ \[Phi][\[Epsilon]] + 
                z\ \[Alpha]\ \[Phi][\[Epsilon]] + \[Epsilon]\ \[Phi][\
\[Epsilon]]\ \[CapitalPsi][\[Epsilon]])\)\), "]"}]}]], "Output"],

Cell[BoxData[
    RowBox[{\(-\((z + \[Epsilon]\ \[CapitalPi][\[Epsilon]])\)\), " ", 
      RowBox[{
        SubsuperscriptBox["u", "2", "\[Prime]",
          MultilineFunction->None], 
        "[", \(Be\_2 + \[Theta]e\_2 + z\ \[Epsilon]\ \[Theta]e\_2 - 
          z\ \[Epsilon]\ \[Theta][\[Epsilon]] - \[Epsilon]\^2\ \[Theta][\
\[Epsilon]]\ \[CapitalPi][\[Epsilon]] + \[Epsilon]\ \[Theta]e\_1\ \((z + \
\[Epsilon]\ \[CapitalPi][\[Epsilon]])\) - y\ \[Epsilon]\ \[Phi][\[Epsilon]] - 
          z\ \[Alpha]\ \[Epsilon]\ \[Phi][\[Epsilon]] - \[Epsilon]\^2\ \
\[Phi][\[Epsilon]]\ \[CapitalPsi][\[Epsilon]]\), "]"}]}]], "Output"],

Cell[BoxData[
    RowBox[{\((y + z\ \[Alpha] + \[Epsilon]\ \[CapitalPsi][\[Epsilon]])\), 
      " ", 
      RowBox[{
        SubsuperscriptBox["u", "1", "\[Prime]",
          MultilineFunction->None], 
        "[", \(Be\_1 + \[Theta]e\_1\ \((1 - \[Epsilon]\^2\ \[CapitalPi][\
\[Epsilon]])\) + \[Epsilon]\ \((z\ \[Theta][\[Epsilon]] + \[Epsilon]\ \
\[Theta][\[Epsilon]]\ \[CapitalPi][\[Epsilon]] + y\ \[Phi][\[Epsilon]] + 
                z\ \[Alpha]\ \[Phi][\[Epsilon]] + \[Epsilon]\ \[Phi][\
\[Epsilon]]\ \[CapitalPsi][\[Epsilon]])\)\), "]"}]}]], "Output"],

Cell[BoxData[
    RowBox[{\(-\((y + 
            z\ \[Alpha] + \[Epsilon]\ \[CapitalPsi][\[Epsilon]])\)\), " ", 
      RowBox[{
        SubsuperscriptBox["u", "2", "\[Prime]",
          MultilineFunction->None], 
        "[", \(Be\_2 + \[Theta]e\_2 + z\ \[Epsilon]\ \[Theta]e\_2 - 
          z\ \[Epsilon]\ \[Theta][\[Epsilon]] - \[Epsilon]\^2\ \[Theta][\
\[Epsilon]]\ \[CapitalPi][\[Epsilon]] + \[Epsilon]\ \[Theta]e\_1\ \((z + \
\[Epsilon]\ \[CapitalPi][\[Epsilon]])\) - y\ \[Epsilon]\ \[Phi][\[Epsilon]] - 
          z\ \[Alpha]\ \[Epsilon]\ \[Phi][\[Epsilon]] - \[Epsilon]\^2\ \
\[Phi][\[Epsilon]]\ \[CapitalPsi][\[Epsilon]]\), "]"}]}]], "Output"]
}, Open  ]],

Cell["\<\
The equilibrium equations are really the expectations 0=E{EQMij}. We will \
execute the integrations later, after the Taylor series expansions, since it \
is permissible to interchange the integration and differentiation operations.\
\
\>", "Text"],

Cell[TextData[{
  "\tWe define abbrevations for the derivatives; this helps make the formulas \
more understandable than the ones automatically generated by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(UtilDerivs = {\(\(Derivative[n_]\)[u\_i_]\)[Be\_i_ + \[Theta]e\_i_] -> 
          A\_i[n]}\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          SubsuperscriptBox["u", "i_", 
            TagBox[\((n_)\),
              Derivative],
            MultilineFunction->None], "[", \(Be\_i_ + \[Theta]e\_i_\), "]"}], 
        "\[Rule]", \(A\_i[n]\)}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "We want to replace derivatives of the utility function, the ",
  Cell[BoxData[
      \(TraditionalForm\`A\_i[m]\)]],
  " terms, with risk tolerance, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\_i\)]],
  ", skew tolerance, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_i\)]],
  ", and kurtosis tolerance, ",
  Cell[BoxData[
      \(\[Kappa]\_i\)]],
  ". The next substitution rule does that."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(UtilParams\  = \ {A\_i_[2] \[Rule] \(-\(A\_i[1]\/\[Tau]\_i\)\), 
        A\_i_[3] \[Rule] \(2\ \[Rho]\_i\ A\_i[1]\)\/\[Tau]\_i\^2, 
        A\_i_[4] \[Rule] \(3\ \[Kappa]\_i\ A\_i[1]\)\/\[Tau]\_i\^3, 
        A\_i_[1] \[Rule] \ 1}\)], "Input"],

Cell[BoxData[
    \({A\_i_[2] \[Rule] \(-\(A\_i[1]\/\[Tau]\_i\)\), 
      A\_i_[3] \[Rule] \(2\ \[Rho]\_i\ A\_i[1]\)\/\[Tau]\_i\%2, 
      A\_i_[4] \[Rule] \(3\ \[Kappa]\_i\ A\_i[1]\)\/\[Tau]\_i\%3, 
      A\_i_[1] \[Rule] 1}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "It is often useful to refer to the social risk tolerance, ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ", and express type ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " risk tolerance as a share, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Nu]\_i\)]],
  ", of total risk tolerance. The following replacement rule allows us to do \
that."
}], "Text"],

Cell[BoxData[
    \(\(taureps\  = \ {\[Tau]\_1 + \[Tau]\_2 \[Rule] 
            T, \[Tau]\_i_ \[Rule] \(\[Upsilon]\_i\) 
              T, \[Upsilon]\_1 + \[Upsilon]\_2 \[Rule] 1};\)\)], "Input"],

Cell["\<\
We now compute the power series expansions of the four equilibrium \
conditions. We fully expand each series so that the various powers of z and y \
are gathered together. This is necessary for our integration approach to \
work.\
\>", "Text"],

Cell[BoxData[{
    \(\(EqmPow11\  = \ \((Normal[Series[EQM11\ , {\[Epsilon], 0, 6}]] /. 
              sub1)\) //. UtilDerivs;\)\), "\n", 
    \(\(EqmPow11\  = \ Expand[EqmPow11];\)\), "\n", 
    \(\(EqmPow12\  = \ \((Normal[Series[EQM12\ , {\[Epsilon], 0, 6}]] /. 
              sub1)\) //. UtilDerivs;\)\), "\n", 
    \(\(EqmPow12\  = \ Expand[EqmPow12];\)\), "\n", 
    \(\(EqmPow21\  = \ \((Normal[Series[EQM21\ , {\[Epsilon], 0, 6}]] /. 
              sub1)\) //. UtilDerivs;\)\), "\n", 
    \(\(EqmPow21\  = \ Expand[EqmPow21];\)\), "\n", 
    \(\(EqmPow22\  = \ \((Normal[Series[EQM22\ , {\[Epsilon], 0, 6}]] /. 
              sub1)\) //. UtilDerivs;\)\), "\n", 
    \(\(EqmPow22\  = \ Expand[EqmPow22];\)\)}], "Input"],

Cell["\<\
We now take the expectation of each equilibrium equation's power series. \
Since z and y are the only random variables, we replace each power of z and y \
and each crossproduct by the appropriate moment.\
\>", "Text"],

Cell[BoxData[{
    \(\(EqmPow11\  = \ EqmPow11 //. moments;\)\), "\n", 
    \(\(EqmPow12\  = \ EqmPow12 //. moments;\)\), "\n", 
    \(\(EqmPow21\  = \ EqmPow21 //. moments;\)\), "\n", 
    \(\(EqmPow22\  = \ EqmPow22 //. moments;\)\)}], "Input"],

Cell["\<\
The final step in constructing the equilibrium expressions is to collect \
terms of like powers of \[Epsilon] and list the coefficients of each power of \
\[Epsilon]. This puts the equations in the proper arrangement for solving the \
problem.\
\>", "Text"],

Cell[BoxData[{
    \(\(Eqns11\  = \ CoefficientList[EqmPow11, \[Epsilon]];\)\), "\n", 
    \(\(Eqns12\  = \ CoefficientList[EqmPow12, \[Epsilon]];\)\), "\n", 
    \(\(Eqns21\  = \ CoefficientList[EqmPow21, \[Epsilon]];\)\), "\n", 
    \(\(Eqns22\  = \ CoefficientList[EqmPow22, \[Epsilon]];\)\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solve the individual equations in sequence", "Section"],

Cell[CellGroupData[{

Cell["Equation 1:", "Subsection"],

Cell[TextData[{
  "\tThe coefficients of the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\^0\)]],
  " components of the equilibrium power series should be zero. We now check \
what they are."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Eqns11[\([1]\)], \ Eqns21[\([1]\)], \ Eqns12[\([1]\)], \ 
      Eqns22[\([1]\)]}\)], "Input"],

Cell[BoxData[
    \({0, 0, 0, 0}\)], "Output"]
}, Open  ]],

Cell["\<\
This shows that we can continue. If this were not a vector of zeroes then we \
would know that our parameterization did not fulfill the necessary conditions \
of the Bifurcation Theorem.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Equation 2:", "Subsection"],

Cell["\<\
\tWe compute the bifurcation point by choosing (\[Theta][0],\[Phi][0],\
\[CapitalPsi][0],\[CapitalPi][0]) so that the \[Epsilon] components of the \
equilibrium equation expansion are zero. We first list the equations\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Eq1 = \(Eqns11[\([2]\)] // Simplify\) // Expand\), "\n", 
    \(Eq2 = \(Eqns21[\([2]\)] // Simplify\) // Expand\), "\n", 
    \(Eq3 = \(Eqns12[\([2]\)] // Simplify\) // Expand\), "\n", 
    \(Eq4 = \(Eqns22[\([2]\)] // Simplify\) // Expand\)}], "Input"],

Cell[BoxData[
    \(\[CapitalPi][0]\ A\_1[1] + \[Theta][0]\ A\_1[2] + \[Alpha]\ \[Phi][
          0]\ A\_1[2]\)], "Output"],

Cell[BoxData[
    \(\(-\[CapitalPi][0]\)\ A\_2[1] - \[Theta]e\_1\ A\_2[
          2] - \[Theta]e\_2\ A\_2[2] + \[Theta][0]\ A\_2[
          2] + \[Alpha]\ \[Phi][0]\ A\_2[2]\)], "Output"],

Cell[BoxData[
    \(\[CapitalPsi][0]\ A\_1[1] + \[Alpha]\ \[Theta][0]\ A\_1[
          2] + \[Alpha]\^2\ \[Phi][0]\ A\_1[2] + \[Mu]\_\(0, 2\)\ \[Phi][
          0]\ A\_1[2]\)], "Output"],

Cell[BoxData[
    \(\(-\[CapitalPsi][0]\)\ A\_2[1] - \[Alpha]\ \[Theta]e\_1\ A\_2[
          2] - \[Alpha]\ \[Theta]e\_2\ A\_2[2] + \[Alpha]\ \[Theta][0]\ A\_2[
          2] + \[Alpha]\^2\ \[Phi][0]\ A\_2[2] + \[Mu]\_\(0, 2\)\ \[Phi][
          0]\ A\_2[2]\)], "Output"]
}, Open  ]],

Cell["We next solve for bifurcation point.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\ \)\(BifPt = \ \(Solve[{Eq1 \[Equal] 0, \ Eq2 \[Equal] 0, \ 
            Eq3 \[Equal] 0, \ 
            Eq4 \[Equal] 0}, {\ \[Theta][0], \[Phi][0], \[CapitalPsi][
              0], \[CapitalPi][0]}]\)[\([1]\)]\)\)\)], "Input"],

Cell[BoxData[
    \({\[CapitalPsi][
          0] \[Rule] \(-\(\(\[Alpha]\ A\_1[
                  2]\ \((\[Theta]e\_1\ A\_2[2] + \[Theta]e\_2\ A\_2[
                        2])\)\)\/\(A\_1[2]\ A\_2[1] + 
                A\_1[1]\ A\_2[2]\)\)\), \[Theta][
          0] \[Rule] \(A\_1[1]\ \((\[Theta]e\_1\ A\_2[2] + \[Theta]e\_2\ \
A\_2[2])\)\)\/\(A\_1[2]\ A\_2[1] + A\_1[1]\ A\_2[2]\), \[Phi][0] \[Rule] 
        0, \[CapitalPi][
          0] \[Rule] \(-\(\(A\_1[
                  2]\ \((\[Theta]e\_1\ A\_2[2] + \[Theta]e\_2\ A\_2[
                        2])\)\)\/\(A\_1[2]\ A\_2[1] + 
                A\_1[1]\ A\_2[2]\)\)\)}\)], "Output"]
}, Open  ]],

Cell["\<\
We simplify the expression, bringing together common factors.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BifPt\  = BifPt // Simplify\)], "Input"],

Cell[BoxData[
    \({\[CapitalPsi][
          0] \[Rule] \(-\(\(\[Alpha]\ \((\[Theta]e\_1 + \[Theta]e\_2)\)\ A\_1[
                  2]\ A\_2[2]\)\/\(A\_1[2]\ A\_2[1] + 
                A\_1[1]\ A\_2[2]\)\)\), \[Theta][
          0] \[Rule] \(\((\[Theta]e\_1 + \[Theta]e\_2)\)\ A\_1[1]\ \
A\_2[2]\)\/\(A\_1[2]\ A\_2[1] + A\_1[1]\ A\_2[2]\), \[Phi][0] \[Rule] 
        0, \[CapitalPi][
          0] \[Rule] \(-\(\(\((\[Theta]e\_1 + \[Theta]e\_2)\)\ A\_1[2]\ A\_2[
                  2]\)\/\(A\_1[2]\ A\_2[1] + 
                A\_1[1]\ A\_2[2]\)\)\)}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "We next simplify by using the equilibrium conditions. Essentially, we want \
to replace all occurrences of ",
  Cell[BoxData[
      \(\[Theta]e\_1 + \[Theta]e\_2\)]],
  " terms, the aggregate endowment of the risky asset, with its value, 1. In \
geneal, we let \[CapitalTheta] be the total endowment of the risky asset; we \
set \[CapitalTheta]=1. EqmSubs defines various substitutions that express the \
identity ",
  Cell[BoxData[
      \(\[Theta]e\_2 + \[Theta]e\_1 = \[CapitalTheta]\)]],
  ", and",
  "vec = - ",
  " allow us to simplify various expressions."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[CapitalTheta] = 1; \ 
    EqmSubs\  = \ {\[Theta]e\_2 + \[Theta]e\_1 \[Rule] \[CapitalTheta], \
\[Theta]e\_2 + \[Theta]e\_1 - \[CapitalTheta] \[Rule] 
          0, \[CapitalTheta] - \[Theta]e\_2 - \[Theta]e\_1 \[Rule] 
          0}\)], "Input"],

Cell[BoxData[
    \({\[Theta]e\_1 + \[Theta]e\_2 \[Rule] 
        1, \(-1\) + \[Theta]e\_1 + \[Theta]e\_2 \[Rule] 0, 
      1 - \[Theta]e\_1 - \[Theta]e\_2 \[Rule] 0}\)], "Output"]
}, Open  ]],

Cell["Simplify BifPt by uskng the substitutions in EqmSubs", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BifPt\  = BifPt //. EqmSubs\)], "Input"],

Cell[BoxData[
    \({\[CapitalPsi][
          0] \[Rule] \(-\(\(\[Alpha]\ A\_1[2]\ A\_2[
                  2]\)\/\(A\_1[2]\ A\_2[1] + A\_1[1]\ A\_2[2]\)\)\), \[Theta][
          0] \[Rule] \(A\_1[1]\ A\_2[2]\)\/\(A\_1[2]\ A\_2[1] + A\_1[1]\ \
A\_2[2]\), \[Phi][0] \[Rule] 
        0, \[CapitalPi][
          0] \[Rule] \(-\(\(A\_1[2]\ A\_2[2]\)\/\(A\_1[2]\ A\_2[1] + 
                A\_1[1]\ A\_2[2]\)\)\)}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "We do not like the utility derivatives, ",
  Cell[BoxData[
      \(\(\(\ \)\(A\_i[j]\)\)\)]],
  ". We apply substitutions contained in ",
  "UtilParams",
  ", defined above, that replace utility derivatives with indices such as \
risk tolerance."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BifPt\  = \ BifPt //. UtilParams\)], "Input"],

Cell[BoxData[
    \({\[CapitalPsi][
          0] \[Rule] \(-\(\[Alpha]\/\(\[Tau]\_1\ \((\(-\(1\/\[Tau]\_1\)\) - 
                    1\/\[Tau]\_2)\)\ \[Tau]\_2\)\)\), \[Theta][
          0] \[Rule] \(-\(1\/\(\((\(-\(1\/\[Tau]\_1\)\) - 
                    1\/\[Tau]\_2)\)\ \[Tau]\_2\)\)\), \[Phi][0] \[Rule] 
        0, \[CapitalPi][
          0] \[Rule] \(-\(1\/\(\[Tau]\_1\ \((\(-\(1\/\[Tau]\_1\)\) - 
                    1\/\[Tau]\_2)\)\ \[Tau]\_2\)\)\)}\)], "Output"]
}, Open  ]],

Cell["\<\
We need to simplify this expression for BifPt. The Simplify command can \
handle this for us. (In general, one must be careful using the Simplify \
command since it can often take a long time to find the desired \
simplification or it will find a simplification other than the one you want.) \
\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(BifPt\  = \ BifPt // Simplify\)], "Input"],

Cell[BoxData[
    \({\[CapitalPsi][0] \[Rule] \[Alpha]\/\(\[Tau]\_1 + \[Tau]\_2\), \[Theta][
          0] \[Rule] \[Tau]\_1\/\(\[Tau]\_1 + \[Tau]\_2\), \[Phi][0] \[Rule] 
        0, \[CapitalPi][0] \[Rule] 1\/\(\[Tau]\_1 + \[Tau]\_2\)}\)], "Output"]
}, Open  ]],

Cell["\<\
We now have an intuitive expression for the bifurcation point. The procedure \
was direct: solve for the bifurcation point in terms of utility derivatives \
and endowments, and then apply various simplifications to transform the \
solution into an expression involving elasticities and shares. Below we will \
apply similar sequences of simplifications without explanation.\
\>", "Text"],

Cell[TextData[{
  "The bifurcation point conforms to basic intutions. The risk premium, ",
  Cell[BoxData[
      \(\[CapitalPi][0]\)]],
  ", equals the inverse of the total risk tolerance,  ",
  Cell[BoxData[
      \(1\/\(\[Tau]\_1 + \[Tau]\_2\)\)]],
  ". Type 1 holdings of equity equals it share of social risk tolerance. The \
risk premium of the derivative asset ",
  Cell[BoxData[
      \(TraditionalForm\`Y\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPsi][0]\)]],
  ", equals ",
  Cell[BoxData[
      \(\[Alpha]\/\(\[Tau]\_1 + \[Tau]\_2\)\)]],
  "which is the product of the risk premium of equity and the covariance of \
",
  Cell[BoxData[
      \(TraditionalForm\`Y\)]],
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  ". (This is equation (32) in the paper). The most surprising result is that \
the asymptotic holding of the derivative asset is zero. This does not mean \
that there is no demand for the derivative; it means that demand is smaller \
than order 0. We will see below that demand is of order \[Epsilon]."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Equation 3:", "Subsection"],

Cell[TextData[{
  "We next compute \
(\[Theta]'[0],\[Phi]'[0],\[CapitalPsi]'[0],\[CapitalPi]'[0]) by setting the \
",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\^2\)]],
  " components of the equilibrium equations Taylor series expansions equal to \
zero. We immediately make the substitutions stated in ",
  "UtilParams",
  "."
}], "Text"],

Cell[BoxData[{
    \(\(Eq1\  = \ Eqns11[\([3]\)] //. UtilParams // Expand;\)\), "\n", 
    \(\(Eq2\  = \ Eqns21[\([3]\)] //. UtilParams // Expand;\)\), "\n", 
    \(\(Eq3\  = \ Eqns12[\([3]\)] //. UtilParams // Expand;\)\), "\n", 
    \(\(Eq4\  = \ Eqns22[\([3]\)] //. UtilParams // Expand;\)\)}], "Input"],

Cell["Here is the first equation; the rest are similar.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eq1\)], "Input"],

Cell[BoxData[
    RowBox[{\(\(\[Rho]\_1\ \[Mu]\_\(3, 0\)\ \[Theta][0]\^2\)\/\[Tau]\_1\%2\), 
      "+", \(\(2\ \[Rho]\_1\ \[Mu]\_\(2, 1\)\ \[Theta][0]\ \[Phi][
              0]\)\/\[Tau]\_1\%2\), 
      "+", \(\(2\ \[Alpha]\ \[Rho]\_1\ \[Mu]\_\(3, 0\)\ \[Theta][0]\ \[Phi][
              0]\)\/\[Tau]\_1\%2\), 
      "+", \(\(\[Rho]\_1\ \[Mu]\_\(1, 2\)\ \[Phi][0]\^2\)\/\[Tau]\_1\%2\), 
      "+", \(\(2\ \[Alpha]\ \[Rho]\_1\ \[Mu]\_\(2, 1\)\ \
\[Phi][0]\^2\)\/\[Tau]\_1\%2\), 
      "+", \(\(\[Alpha]\^2\ \[Rho]\_1\ \[Mu]\_\(3, 0\)\ \
\[Phi][0]\^2\)\/\[Tau]\_1\%2\), "-", 
      FractionBox[
        RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]",
            MultilineFunction->None], "[", "0", "]"}], \(\[Tau]\_1\)], "+", 
      RowBox[{
        SuperscriptBox["\[CapitalPi]", "\[Prime]",
          MultilineFunction->None], "[", "0", "]"}], "-", 
      FractionBox[
        RowBox[{"\[Alpha]", " ", 
          RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]",
              MultilineFunction->None], "[", "0", 
            "]"}]}], \(\[Tau]\_1\)]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "We now solve for the unknowns, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Theta]'\)[0]\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(\[Phi]'\)[0]\)\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CapitalPsi]'\)[0]\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CapitalPi]'\)[0]\)]],
  ". We suppress printing the first set of results since they take up too \
much space. The substitutions we make below will produce comprehensible \
expressions."
}], "Text"],

Cell[BoxData[
    \(\(Sol2\  = \ \(Solve[{Eq1 \[Equal] 0, \ Eq2 \[Equal] 0, \ 
              Eq3 \[Equal] 0, \ 
              Eq4 \[Equal] 0}, {\ \(\[Theta]'\)[0], \(\[Phi]'\)[
                0], \(\[CapitalPsi]'\)[0], \(\[CapitalPi]'\)[
                0]}]\)[\([1]\)];\)\)], "Input"],

Cell[TextData[{
  "The solution involves , ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta][0]\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\[Phi][0]\)\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPsi][0]\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPi][0]\)]],
  ". We now replace these terms with the values found in our bifurcation \
point solution, BifPt."
}], "Text"],

Cell[BoxData[
    \(\(Sol2\  = \ Sol2 /. BifPt;\)\)], "Input"],

Cell[TextData[{
  "Note: we could have made these substitutions when we defined Eq1, Eq2, \
etc, but that would not be wise. If we had done that then the expressions in \
Eq1, ",
  "Eq2",
  ", etc., would have been larger, making more work for ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". This would not have been a major problem for this set of equations, but \
becomes important when we move to higher-order terms where the solutions \
become more complex."
}], "Text"],

Cell["\<\
We next simplify the result which produces a fairly compact form.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Sol2\  = \ Sol2 // Simplify;\)\), "\[IndentingNewLine]", 
    \(Sol2 // TableForm\)}], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            RowBox[{
              RowBox[{
                SuperscriptBox["\[CapitalPsi]", "\[Prime]",
                  MultilineFunction->None], "[", "0", "]"}], 
              "\[Rule]", \(-\(\(\((\[Rho]\_1\ \[Tau]\_1\ \[Tau]\_2 + \
\[Rho]\_2\ \((\((\(-1\) + \[Theta]e\_1 + \[Theta]e\_2)\)\ \[Tau]\_1 + \((\
\[Theta]e\_1 + \[Theta]e\_2)\)\ \[Tau]\_2)\)\^2)\)\ \((\[Mu]\_\(2, 1\) + \
\[Alpha]\ \[Mu]\_\(3, 0\))\)\)\/\(\[Tau]\_2\ \((\[Tau]\_1 + \[Tau]\_2)\)\^3\)\
\)\)}]},
          {
            RowBox[{
              RowBox[{
                SuperscriptBox["\[Theta]", "\[Prime]",
                  MultilineFunction->None], "[", "0", "]"}], 
              "\[Rule]", \(\(\[Tau]\_1\ \((\(-\[Rho]\_1\)\ \[Tau]\_2\%2 + \
\[Rho]\_2\ \((\((\(-1\) + \[Theta]e\_1 + \[Theta]e\_2)\)\ \[Tau]\_1 + \((\
\[Theta]e\_1 + \[Theta]e\_2)\)\ \[Tau]\_2)\)\^2)\)\ \((\[Alpha]\ \[Mu]\_\(2, \
1\) - \[Mu]\_\(0, 2\)\ \[Mu]\_\(3, 0\))\)\)\/\(\[Tau]\_2\ \((\[Tau]\_1 + \
\[Tau]\_2)\)\^3\ \[Mu]\_\(0, 2\)\)\)}]},
          {
            RowBox[{
              RowBox[{
                SuperscriptBox["\[Phi]", "\[Prime]",
                  MultilineFunction->None], "[", "0", "]"}], 
              "\[Rule]", \(-\(\(\[Tau]\_1\ \((\(-\[Rho]\_1\)\ \[Tau]\_2\%2 + \
\[Rho]\_2\ \((\((\(-1\) + \[Theta]e\_1 + \[Theta]e\_2)\)\ \[Tau]\_1 + \((\
\[Theta]e\_1 + \[Theta]e\_2)\)\ \[Tau]\_2)\)\^2)\)\ \[Mu]\_\(2, 1\)\)\/\(\
\[Tau]\_2\ \((\[Tau]\_1 + \[Tau]\_2)\)\^3\ \[Mu]\_\(0, 2\)\)\)\)}]},
          {
            RowBox[{
              RowBox[{
                SuperscriptBox["\[CapitalPi]", "\[Prime]",
                  MultilineFunction->None], "[", "0", "]"}], 
              "\[Rule]", \(-\(\(\((\[Rho]\_1\ \[Tau]\_1\ \[Tau]\_2 + \
\[Rho]\_2\ \((\((\(-1\) + \[Theta]e\_1 + \[Theta]e\_2)\)\ \[Tau]\_1 + \((\
\[Theta]e\_1 + \[Theta]e\_2)\)\ \[Tau]\_2)\)\^2)\)\ \[Mu]\_\(3, 0\)\)\/\(\
\[Tau]\_2\ \((\[Tau]\_1 + \[Tau]\_2)\)\^3\)\)\)}]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {Derivative[ 1][ \[CapitalPsi]][ 0] -> Times[ -1, 
          Power[ 
            Subscript[ \[Tau], 2], -1], 
          Power[ 
            Plus[ 
              Subscript[ \[Tau], 1], 
              Subscript[ \[Tau], 2]], -3], 
          Plus[ 
            Times[ 
              Subscript[ \[Rho], 1], 
              Subscript[ \[Tau], 1], 
              Subscript[ \[Tau], 2]], 
            Times[ 
              Subscript[ \[Rho], 2], 
              Power[ 
                Plus[ 
                  Times[ 
                    Plus[ -1, 
                      Subscript[ \[Theta]e, 1], 
                      Subscript[ \[Theta]e, 2]], 
                    Subscript[ \[Tau], 1]], 
                  Times[ 
                    Plus[ 
                      Subscript[ \[Theta]e, 1], 
                      Subscript[ \[Theta]e, 2]], 
                    Subscript[ \[Tau], 2]]], 2]]], 
          Plus[ 
            Subscript[ \[Mu], 2, 1], 
            Times[ \[Alpha], 
              Subscript[ \[Mu], 3, 0]]]], Derivative[ 1][ \[Theta]][ 0] -> 
        Times[ 
          Subscript[ \[Tau], 1], 
          Power[ 
            Subscript[ \[Tau], 2], -1], 
          Power[ 
            Plus[ 
              Subscript[ \[Tau], 1], 
              Subscript[ \[Tau], 2]], -3], 
          Plus[ 
            Times[ -1, 
              Subscript[ \[Rho], 1], 
              Power[ 
                Subscript[ \[Tau], 2], 2]], 
            Times[ 
              Subscript[ \[Rho], 2], 
              Power[ 
                Plus[ 
                  Times[ 
                    Plus[ -1, 
                      Subscript[ \[Theta]e, 1], 
                      Subscript[ \[Theta]e, 2]], 
                    Subscript[ \[Tau], 1]], 
                  Times[ 
                    Plus[ 
                      Subscript[ \[Theta]e, 1], 
                      Subscript[ \[Theta]e, 2]], 
                    Subscript[ \[Tau], 2]]], 2]]], 
          Power[ 
            Subscript[ \[Mu], 0, 2], -1], 
          Plus[ 
            Times[ \[Alpha], 
              Subscript[ \[Mu], 2, 1]], 
            Times[ -1, 
              Subscript[ \[Mu], 0, 2], 
              Subscript[ \[Mu], 3, 0]]]], Derivative[ 1][ \[Phi]][ 0] -> 
        Times[ -1, 
          Subscript[ \[Tau], 1], 
          Power[ 
            Subscript[ \[Tau], 2], -1], 
          Power[ 
            Plus[ 
              Subscript[ \[Tau], 1], 
              Subscript[ \[Tau], 2]], -3], 
          Plus[ 
            Times[ -1, 
              Subscript[ \[Rho], 1], 
              Power[ 
                Subscript[ \[Tau], 2], 2]], 
            Times[ 
              Subscript[ \[Rho], 2], 
              Power[ 
                Plus[ 
                  Times[ 
                    Plus[ -1, 
                      Subscript[ \[Theta]e, 1], 
                      Subscript[ \[Theta]e, 2]], 
                    Subscript[ \[Tau], 1]], 
                  Times[ 
                    Plus[ 
                      Subscript[ \[Theta]e, 1], 
                      Subscript[ \[Theta]e, 2]], 
                    Subscript[ \[Tau], 2]]], 2]]], 
          Power[ 
            Subscript[ \[Mu], 0, 2], -1], 
          Subscript[ \[Mu], 2, 1]], Derivative[ 1][ \[CapitalPi]][ 0] -> 
        Times[ -1, 
          Power[ 
            Subscript[ \[Tau], 2], -1], 
          Power[ 
            Plus[ 
              Subscript[ \[Tau], 1], 
              Subscript[ \[Tau], 2]], -3], 
          Plus[ 
            Times[ 
              Subscript[ \[Rho], 1], 
              Subscript[ \[Tau], 1], 
              Subscript[ \[Tau], 2]], 
            Times[ 
              Subscript[ \[Rho], 2], 
              Power[ 
                Plus[ 
                  Times[ 
                    Plus[ -1, 
                      Subscript[ \[Theta]e, 1], 
                      Subscript[ \[Theta]e, 2]], 
                    Subscript[ \[Tau], 1]], 
                  Times[ 
                    Plus[ 
                      Subscript[ \[Theta]e, 1], 
                      Subscript[ \[Theta]e, 2]], 
                    Subscript[ \[Tau], 2]]], 2]]], 
          Subscript[ \[Mu], 3, 0]]}]]], "Output"]
}, Open  ]],

Cell["\<\
We can further simplify it by applying the equilibrium substitutions.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Sol2\  = \ Sol2 /. EqmSubs // Simplify;\)\), "\[IndentingNewLine]", 
    \(Sol2 // TableForm\)}], "Input"],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {
            RowBox[{
              RowBox[{
                SuperscriptBox["\[CapitalPsi]", "\[Prime]",
                  MultilineFunction->None], "[", "0", "]"}], 
              "\[Rule]", \(-\(\(\((\[Rho]\_1\ \[Tau]\_1 + \[Rho]\_2\ \
\[Tau]\_2)\)\ \((\[Mu]\_\(2, 1\) + \[Alpha]\ \[Mu]\_\(3, \
0\))\)\)\/\((\[Tau]\_1 + \[Tau]\_2)\)\^3\)\)}]},
          {
            RowBox[{
              RowBox[{
                SuperscriptBox["\[Theta]", "\[Prime]",
                  MultilineFunction->None], "[", "0", "]"}], 
              "\[Rule]", \(\(\((\[Rho]\_1 - \[Rho]\_2)\)\ \[Tau]\_1\ \
\[Tau]\_2\ \((\(-\[Alpha]\)\ \[Mu]\_\(2, 1\) + \[Mu]\_\(0, 2\)\ \[Mu]\_\(3, 0\
\))\)\)\/\(\((\[Tau]\_1 + \[Tau]\_2)\)\^3\ \[Mu]\_\(0, 2\)\)\)}]},
          {
            RowBox[{
              RowBox[{
                SuperscriptBox["\[Phi]", "\[Prime]",
                  MultilineFunction->None], "[", "0", "]"}], 
              "\[Rule]", \(\(\((\[Rho]\_1 - \[Rho]\_2)\)\ \[Tau]\_1\ \
\[Tau]\_2\ \[Mu]\_\(2, 1\)\)\/\(\((\[Tau]\_1 + \[Tau]\_2)\)\^3\ \[Mu]\_\(0, 2\
\)\)\)}]},
          {
            RowBox[{
              RowBox[{
                SuperscriptBox["\[CapitalPi]", "\[Prime]",
                  MultilineFunction->None], "[", "0", "]"}], 
              "\[Rule]", \(-\(\(\((\[Rho]\_1\ \[Tau]\_1 + \[Rho]\_2\ \
\[Tau]\_2)\)\ \[Mu]\_\(3, 0\)\)\/\((\[Tau]\_1 + \[Tau]\_2)\)\^3\)\)}]}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {Derivative[ 1][ \[CapitalPsi]][ 0] -> Times[ -1, 
          Power[ 
            Plus[ 
              Subscript[ \[Tau], 1], 
              Subscript[ \[Tau], 2]], -3], 
          Plus[ 
            Times[ 
              Subscript[ \[Rho], 1], 
              Subscript[ \[Tau], 1]], 
            Times[ 
              Subscript[ \[Rho], 2], 
              Subscript[ \[Tau], 2]]], 
          Plus[ 
            Subscript[ \[Mu], 2, 1], 
            Times[ \[Alpha], 
              Subscript[ \[Mu], 3, 0]]]], Derivative[ 1][ \[Theta]][ 0] -> 
        Times[ 
          Plus[ 
            Subscript[ \[Rho], 1], 
            Times[ -1, 
              Subscript[ \[Rho], 2]]], 
          Subscript[ \[Tau], 1], 
          Subscript[ \[Tau], 2], 
          Power[ 
            Plus[ 
              Subscript[ \[Tau], 1], 
              Subscript[ \[Tau], 2]], -3], 
          Power[ 
            Subscript[ \[Mu], 0, 2], -1], 
          Plus[ 
            Times[ -1, \[Alpha], 
              Subscript[ \[Mu], 2, 1]], 
            Times[ 
              Subscript[ \[Mu], 0, 2], 
              Subscript[ \[Mu], 3, 0]]]], Derivative[ 1][ \[Phi]][ 0] -> 
        Times[ 
          Plus[ 
            Subscript[ \[Rho], 1], 
            Times[ -1, 
              Subscript[ \[Rho], 2]]], 
          Subscript[ \[Tau], 1], 
          Subscript[ \[Tau], 2], 
          Power[ 
            Plus[ 
              Subscript[ \[Tau], 1], 
              Subscript[ \[Tau], 2]], -3], 
          Power[ 
            Subscript[ \[Mu], 0, 2], -1], 
          Subscript[ \[Mu], 2, 1]], Derivative[ 1][ \[CapitalPi]][ 0] -> 
        Times[ -1, 
          Power[ 
            Plus[ 
              Subscript[ \[Tau], 1], 
              Subscript[ \[Tau], 2]], -3], 
          Plus[ 
            Times[ 
              Subscript[ \[Rho], 1], 
              Subscript[ \[Tau], 1]], 
            Times[ 
              Subscript[ \[Rho], 2], 
              Subscript[ \[Tau], 2]]], 
          Subscript[ \[Mu], 3, 0]]}]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The solution for ",
  Cell[BoxData[
      RowBox[{
        SuperscriptBox["\[Phi]", "\[Prime]",
          MultilineFunction->None], "[", "0", "]"}]]],
  " in Sol2 proves the assertions in Theorem 9."
}], "Text"],

Cell["If there is no derivative security, then the solution is", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sol2NoY = Sol2 //. NoDeriv\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{
            SuperscriptBox["\[CapitalPsi]", "\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], 
          "\[Rule]", \(-\(\(\[Alpha]\ \((\[Rho]\_1\ \[Tau]\_1 + \[Rho]\_2\ \
\[Tau]\_2)\)\ \[Mu]\_\(3, 0\)\)\/\((\[Tau]\_1 + \[Tau]\_2)\)\^3\)\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], 
          "\[Rule]", \(\(\((\[Rho]\_1 - \[Rho]\_2)\)\ \[Tau]\_1\ \[Tau]\_2\ \
\[Mu]\_\(3, 0\)\)\/\((\[Tau]\_1 + \[Tau]\_2)\)\^3\)}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], "\[Rule]", "0"}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["\[CapitalPi]", "\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], 
          "\[Rule]", \(-\(\(\((\[Rho]\_1\ \[Tau]\_1 + \[Rho]\_2\ \[Tau]\_2)\)\
\ \[Mu]\_\(3, 0\)\)\/\((\[Tau]\_1 + \[Tau]\_2)\)\^3\)\)}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "This proves Theorem 8. The solution for ",
  Cell[BoxData[
      RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "0", "]"}]]],
  " in Sol2NoY proves the assertion in equation (26) and the solution for ",
  Cell[BoxData[
      RowBox[{
        SuperscriptBox["\[CapitalPi]", "\[Prime]",
          MultilineFunction->None], "[", "0", "]"}]]],
  "in ",
  "Sol2",
  "NoY proves the assertion in equation (27)."
}], "Text"],

Cell[CellGroupData[{

Cell["Compute the change in equity demand from introduction of Y", \
"Subsubsection"],

Cell[TextData[{
  "Notice that the presence of ",
  "Y",
  " has no impact on the equity premium derivative, ",
  Cell[BoxData[
      RowBox[{
        SuperscriptBox["\[CapitalPi]", "\[Prime]",
          MultilineFunction->None], "[", "0", "]"}]]],
  ", but it does affect equity demand, ",
  Cell[BoxData[
      RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "0", "]"}]]],
  ". So, we now determine that effect."
}], "Text"],

Cell[TextData[{
  "If there are two assets, then ",
  Cell[BoxData[
      RowBox[{
        SuperscriptBox["\[Theta]", "\[Prime]",
          MultilineFunction->None], "[", "0", "]"}]]],
  " is"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TwoAsset\  = \ \(\(\[Theta]'\)[0] /. BifPt\) /. Sol2\)], "Input"],

Cell[BoxData[
    \(\(\((\[Rho]\_1 - \[Rho]\_2)\)\ \[Tau]\_1\ \[Tau]\_2\ \((\(-\[Alpha]\)\ \
\[Mu]\_\(2, 1\) + \[Mu]\_\(0, 2\)\ \[Mu]\_\(3, 0\))\)\)\/\(\((\[Tau]\_1 + \
\[Tau]\_2)\)\^3\ \[Mu]\_\(0, 2\)\)\)], "Output"]
}, Open  ]],

Cell["\<\
If \[Alpha]=0 then the derivative asset has no impact on equilibrium and it \
is as if it did not exist. The substitutions in NoDeriv (defined above) state \
that the derivative is uncorrelated with equity at all moments, representing \
the case where there is no derivative. Therefore, equity demand in its \
absence is\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(SingleAsset\  = \ TwoAsset /. NoDeriv\)], "Input"],

Cell[BoxData[
    \(\(\((\[Rho]\_1 - \[Rho]\_2)\)\ \[Tau]\_1\ \[Tau]\_2\ \[Mu]\_\(3, \
0\)\)\/\((\[Tau]\_1 + \[Tau]\_2)\)\^3\)], "Output"]
}, Open  ]],

Cell["The change in equity demand is the difference:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\ \)\(TwoAsset\  - \ SingleAsset // Simplify\)\)\)], "Input"],

Cell[BoxData[
    \(\(\[Alpha]\ \((\(-\[Rho]\_1\) + \[Rho]\_2)\)\ \[Tau]\_1\ \[Tau]\_2\ \
\[Mu]\_\(2, 1\)\)\/\(\((\[Tau]\_1 + \[Tau]\_2)\)\^3\ \[Mu]\_\(0, 2\)\)\)], \
"Output"]
}, Open  ]],

Cell["This is the result reported in Theorem 10.", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Equation 4:", "Subsection"],

Cell[TextData[{
  "We next compute (\[Theta]''[0],",
  "\[Phi]",
  "''[0],\[CapitalPsi]''[0],\[CapitalPi]''[0]) by setting the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\^3\)]],
  " components of the equilibrium equations equal to zero."
}], "Text"],

Cell[BoxData[{
    \(\(Eq1\  = \ \(\(\(Eqns11[\([4]\)] //. UtilParams\) /. Sol2\) /. 
              BifPt\) /. {\[Theta]e\_2 \[Rule] \[CapitalTheta] - \
\[Theta]e\_1} // Expand;\)\), "\n", 
    \(\(Eq2\  = \ \(\(\(Eqns21[\([4]\)] //. UtilParams\) /. Sol2\) /. 
              BifPt\) /. {\[Theta]e\_2 \[Rule] \[CapitalTheta] - \
\[Theta]e\_1} // Expand;\)\), "\n", 
    \(\(Eq3\  = \ \(\(\(Eqns12[\([4]\)] //. UtilParams\) /. Sol2\) /. 
              BifPt\) /. {\[Theta]e\_2 \[Rule] \[CapitalTheta] - \
\[Theta]e\_1} // Expand;\)\), "\n", 
    \(\(Eq4\  = \ \(\(\(Eqns22[\([4]\)] //. UtilParams\) /. Sol2\) /. 
              BifPt\) /. {\[Theta]e\_2 \[Rule] \[CapitalTheta] - \
\[Theta]e\_1} // Expand;\)\)}], "Input"],

Cell["Here is the first equation; the rest are similar.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eq1\)], "Input"],

Cell[BoxData[
    RowBox[{\(-\(1\/\((\[Tau]\_1 + \[Tau]\_2)\)\^3\)\), 
      "+", \(\(3\ \[Rho]\_1\)\/\((\[Tau]\_1 + \[Tau]\_2)\)\^3\), 
      "+", \(\[Theta]e\_1\/\(\[Tau]\_1\ \((\[Tau]\_1 + \[Tau]\_2)\)\^2\)\), 
      "-", \(\(2\ \[Theta]e\_1\ \[Rho]\_1\)\/\(\[Tau]\_1\ \((\[Tau]\_1 + \
\[Tau]\_2)\)\^2\)\), 
      "+", \(\(2\ \[Rho]\_1\%2\ \[Tau]\_2\ \[Mu]\_\(2, \
1\)\%2\)\/\(\((\[Tau]\_1 + \[Tau]\_2)\)\^4\ \[Mu]\_\(0, 2\)\)\), 
      "-", \(\(2\ \[Rho]\_1\ \[Rho]\_2\ \[Tau]\_2\ \[Mu]\_\(2, \
1\)\%2\)\/\(\((\[Tau]\_1 + \[Tau]\_2)\)\^4\ \[Mu]\_\(0, 2\)\)\), 
      "+", \(\(2\ \[Rho]\_1\%2\ \[Tau]\_2\ \[Mu]\_\(3, 0\)\%2\)\/\((\[Tau]\_1 \
+ \[Tau]\_2)\)\^4\), 
      "-", \(\(2\ \[Rho]\_1\ \[Rho]\_2\ \[Tau]\_2\ \[Mu]\_\(3, 0\)\%2\)\/\((\
\[Tau]\_1 + \[Tau]\_2)\)\^4\), 
      "+", \(\(\[Kappa]\_1\ \[Mu]\_\(4, 0\)\)\/\(2\ \((\[Tau]\_1 + \[Tau]\_2)\
\)\^3\)\), "-", 
      FractionBox[
        RowBox[{
          SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "0", "]"}], \(2\ \[Tau]\_1\)], "+",
       
      FractionBox[
        RowBox[{
          SuperscriptBox["\[CapitalPi]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "0", "]"}], "2"], "-", 
      FractionBox[
        RowBox[{"\[Alpha]", " ", 
          RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "0", 
            "]"}]}], \(2\ \[Tau]\_1\)]}]], "Output"]
}, Open  ]],

Cell["Solve for the second derivatives", "Text"],

Cell[BoxData[
    \(\(Sol3\  = \ \(Solve[{Eq1 \[Equal] 0, \ Eq2 \[Equal] 0, \ 
              Eq3 \[Equal] 0, \ 
              Eq4 \[Equal] 0}, {\ \(\(\[Theta]'\)'\)[0], \(\[Phi]''\)[
                0], \(\(\[CapitalPsi]'\)'\)[0], \(\(\[CapitalPi]'\)'\)[
                0]}]\)[\([1]\)];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Sol3 = Sol3 // Simplify;\)\), "\[IndentingNewLine]", 
    \(Sol3\)}], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{
            SuperscriptBox["\[CapitalPsi]", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], 
          "\[Rule]", \(-\(\(1\/\(\((\[Tau]\_1 + \[Tau]\_2)\)\^5\ \[Mu]\_\(0, \
2\)\)\)\((2\ \[Alpha]\ \[Rho]\_2\ \((\[Tau]\_1 + \[Tau]\_2)\)\ \((2\ \
\((\(-1\) + \[Theta]e\_1)\)\ \[Tau]\_1 + \((1 + 
                            2\ \[Theta]e\_1)\)\ \[Tau]\_2)\)\ \[Mu]\_\(0, 2\) \
+ 4\ \[Rho]\_1\%2\ \[Tau]\_1\ \[Tau]\_2\ \((\[Mu]\_\(1, 2\)\ \[Mu]\_\(2, 1\) \
+ \[Alpha]\ \[Mu]\_\(2, 1\)\%2 + \[Mu]\_\(0, 2\)\ \[Mu]\_\(2, 1\)\ \
\[Mu]\_\(3, 0\) + \[Alpha]\ \[Mu]\_\(0, 2\)\ \[Mu]\_\(3, 0\)\%2)\) + 
                4\ \[Rho]\_2\%2\ \[Tau]\_1\ \[Tau]\_2\ \((\[Mu]\_\(1, 2\)\ \
\[Mu]\_\(2, 1\) + \[Alpha]\ \[Mu]\_\(2, 1\)\%2 + \[Mu]\_\(0, 2\)\ \[Mu]\_\(2, \
1\)\ \[Mu]\_\(3, 0\) + \[Alpha]\ \[Mu]\_\(0, 2\)\ \[Mu]\_\(3, 0\)\%2)\) - 
                2\ \[Rho]\_1\ \((\[Alpha]\ \((\(-3\) + 
                            2\ \[Theta]e\_1)\)\ \[Tau]\_1\%2\ \[Mu]\_\(0, 2\) \
+ 2\ \[Alpha]\ \[Theta]e\_1\ \[Tau]\_2\%2\ \[Mu]\_\(0, 2\) + \[Tau]\_1\ \
\[Tau]\_2\ \((4\ \[Rho]\_2\ \[Mu]\_\(2, 1\)\ \((\[Mu]\_\(1, 2\) + \[Alpha]\ \
\[Mu]\_\(2, 1\))\) + \[Mu]\_\(0, 2\)\ \((\(-3\)\ \[Alpha] + 
                                  4\ \[Alpha]\ \[Theta]e\_1 + 
                                  4\ \[Rho]\_2\ \[Mu]\_\(3, 0\)\ \
\((\[Mu]\_\(2, 1\) + \[Alpha]\ \[Mu]\_\(3, 0\))\))\))\))\) + \((\[Tau]\_1 + \
\[Tau]\_2)\)\ \((\[Kappa]\_1\ \[Tau]\_1 + \[Kappa]\_2\ \[Tau]\_2)\)\ \
\[Mu]\_\(0, 2\)\ \((\[Mu]\_\(3, 1\) + \[Alpha]\ \[Mu]\_\(4, 0\))\))\)\)\)}], 
        ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Theta]", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], 
          "\[Rule]", \(\(1\/\(\((\[Tau]\_1 + \[Tau]\_2)\)\^5\ \[Mu]\_\(0, 2\)\
\%2\)\)\((\(-2\)\ \((\(-1\) + \[Theta]e\_1)\)\ \((\(-1\) + 
                    2\ \[Rho]\_2)\)\ \[Tau]\_1\%3\ \[Mu]\_\(0, 2\)\%2 + 
              2\ \[Theta]e\_1\ \((1 - 
                    2\ \[Rho]\_1)\)\ \[Tau]\_2\%3\ \[Mu]\_\(0, 2\)\%2 + \
\[Tau]\_1\%2\ \[Tau]\_2\ \((4\ \[Alpha]\ \[Rho]\_2\ \((\(-\[Rho]\_1\) + \
\[Rho]\_2)\)\ \[Mu]\_\(1, 2\)\ \[Mu]\_\(2, 1\) + \[Mu]\_\(0, 2\)\ \((4\ \
\[Rho]\_1\ \[Rho]\_2\ \[Mu]\_\(2, 1\)\ \((\[Mu]\_\(2, 1\) - \[Alpha]\ \[Mu]\_\
\(3, 0\))\) - 
                          4\ \[Rho]\_2\%2\ \[Mu]\_\(2, 1\)\ \((\[Mu]\_\(2, \
1\) - \[Alpha]\ \[Mu]\_\(3, 0\))\) + \[Alpha]\ \((\(-\[Kappa]\_1\) + \[Kappa]\
\_2)\)\ \[Mu]\_\(3, 1\))\) + \[Mu]\_\(0, 2\)\%2\ \((\(-4\) + 2\ \[Rho]\_2 - 
                          2\ \[Theta]e\_1\ \((\(-3\) + 2\ \[Rho]\_1 + 
                                4\ \[Rho]\_2)\) - 
                          4\ \[Rho]\_2\%2\ \[Mu]\_\(3, 0\)\%2 + \[Rho]\_1\ \
\((6 + 4\ \[Rho]\_2\ \[Mu]\_\(3, 0\)\%2)\) + \[Kappa]\_1\ \[Mu]\_\(4, 0\) - \
\[Kappa]\_2\ \[Mu]\_\(4, 0\))\))\) - \[Tau]\_1\ \[Tau]\_2\%2\ \((4\ \[Alpha]\ \
\[Rho]\_1\ \((\[Rho]\_1 - \[Rho]\_2)\)\ \[Mu]\_\(1, 2\)\ \[Mu]\_\(2, 1\) + \
\[Mu]\_\(0, 2\)\ \((\(-4\)\ \[Rho]\_1\%2\ \[Mu]\_\(2, 1\)\ \((\[Mu]\_\(2, 1\) \
- \[Alpha]\ \[Mu]\_\(3, 0\))\) + 
                          4\ \[Rho]\_1\ \[Rho]\_2\ \[Mu]\_\(2, 1\)\ \
\((\[Mu]\_\(2, 1\) - \[Alpha]\ \[Mu]\_\(3, 0\))\) + \[Alpha]\ \((\[Kappa]\_1 \
- \[Kappa]\_2)\)\ \[Mu]\_\(3, 1\))\) + \[Mu]\_\(0, 2\)\%2\ \((2 + 
                          2\ \[Rho]\_2 + 
                          2\ \[Theta]e\_1\ \((\(-3\) + 4\ \[Rho]\_1 + 
                                2\ \[Rho]\_2)\) - 
                          4\ \[Rho]\_1\%2\ \[Mu]\_\(3, 0\)\%2 + \[Rho]\_1\ \
\((\(-6\) + 
                                4\ \[Rho]\_2\ \[Mu]\_\(3, 0\)\%2)\) - \
\[Kappa]\_1\ \[Mu]\_\(4, 0\) + \[Kappa]\_2\ \[Mu]\_\(4, 0\))\))\))\)\)}], ",",
         
        RowBox[{
          RowBox[{
            SuperscriptBox["\[Phi]", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], 
          "\[Rule]", \(\(1\/\(\((\[Tau]\_1 + \[Tau]\_2)\)\^5\ \[Mu]\_\(0, 2\)\
\%2\)\)\((\[Tau]\_1\ \[Tau]\_2\ \((\(-4\)\ \[Rho]\_2\%2\ \[Tau]\_1\ \
\[Mu]\_\(2, 1\)\ \((\[Mu]\_\(1, 2\) + \[Mu]\_\(0, 2\)\ \[Mu]\_\(3, 0\))\) + 
                  4\ \[Rho]\_1\ \[Rho]\_2\ \((\[Tau]\_1 - \[Tau]\_2)\)\ \[Mu]\
\_\(2, 1\)\ \((\[Mu]\_\(1, 2\) + \[Mu]\_\(0, 2\)\ \[Mu]\_\(3, 0\))\) + 
                  4\ \[Rho]\_1\%2\ \[Tau]\_2\ \[Mu]\_\(2, 1\)\ \((\[Mu]\_\(1, \
2\) + \[Mu]\_\(0, 2\)\ \[Mu]\_\(3, 0\))\) + \((\[Kappa]\_1 - \[Kappa]\_2)\)\ \
\((\[Tau]\_1 + \[Tau]\_2)\)\ \[Mu]\_\(0, 2\)\ \[Mu]\_\(3, 1\))\))\)\)}], ",", 
        
        RowBox[{
          RowBox[{
            SuperscriptBox["\[CapitalPi]", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "0", "]"}], 
          "\[Rule]", \(-\(\(1\/\(\((\[Tau]\_1 + \[Tau]\_2)\)\^5\ \[Mu]\_\(0, \
2\)\)\)\((2\ \[Rho]\_2\ \((\[Tau]\_1 + \[Tau]\_2)\)\ \((2\ \((\(-1\) + \
\[Theta]e\_1)\)\ \[Tau]\_1 + \((1 + 
                            2\ \[Theta]e\_1)\)\ \[Tau]\_2)\)\ \[Mu]\_\(0, 2\) \
+ 4\ \[Rho]\_1\%2\ \[Tau]\_1\ \[Tau]\_2\ \((\[Mu]\_\(2, 1\)\%2 + \[Mu]\_\(0, \
2\)\ \[Mu]\_\(3, 0\)\%2)\) + 
                4\ \[Rho]\_2\%2\ \[Tau]\_1\ \[Tau]\_2\ \((\[Mu]\_\(2, 1\)\%2 \
+ \[Mu]\_\(0, 2\)\ \[Mu]\_\(3, 0\)\%2)\) - 
                2\ \[Rho]\_1\ \((\((\(-3\) + 
                            2\ \[Theta]e\_1)\)\ \[Tau]\_1\%2\ \[Mu]\_\(0, 2\) \
+ 2\ \[Theta]e\_1\ \[Tau]\_2\%2\ \[Mu]\_\(0, 2\) + \[Tau]\_1\ \[Tau]\_2\ \((4\
\ \[Rho]\_2\ \[Mu]\_\(2, 1\)\%2 + \[Mu]\_\(0, 2\)\ \((\(-3\) + 
                                  4\ \[Theta]e\_1 + 
                                  4\ \[Rho]\_2\ \[Mu]\_\(3, 0\)\%2)\))\))\) + \
\((\[Tau]\_1 + \[Tau]\_2)\)\ \((\[Kappa]\_1\ \[Tau]\_1 + \[Kappa]\_2\ \
\[Tau]\_2)\)\ \[Mu]\_\(0, 2\)\ \[Mu]\_\(4, 0\))\)\)\)}]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Change in equity risk premium", "Subsubsection"],

Cell["\<\
The presence of Y does affect \[CapitalPi]''[0]. pi2 expresses this term.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(pi2\  = \ \(\(\(\[CapitalPi]'\)'\)[0] /. Sol3 // Together\) // 
        Expand\)], "Input"],

Cell[BoxData[
    \(\(-\(\(6\ \[Rho]\_1\ \[Tau]\_1\%2\)\/\((\[Tau]\_1 + \[Tau]\_2)\)\^5\)\) \
+ \(4\ \[Theta]e\_1\ \[Rho]\_1\ \[Tau]\_1\%2\)\/\((\[Tau]\_1 + \
\[Tau]\_2)\)\^5 + \(4\ \[Rho]\_2\ \[Tau]\_1\%2\)\/\((\[Tau]\_1 + \[Tau]\_2)\)\
\^5 - \(4\ \[Theta]e\_1\ \[Rho]\_2\ \[Tau]\_1\%2\)\/\((\[Tau]\_1 + \[Tau]\_2)\
\)\^5 - \(6\ \[Rho]\_1\ \[Tau]\_1\ \[Tau]\_2\)\/\((\[Tau]\_1 + \
\[Tau]\_2)\)\^5 + \(8\ \[Theta]e\_1\ \[Rho]\_1\ \[Tau]\_1\ \[Tau]\_2\)\/\((\
\[Tau]\_1 + \[Tau]\_2)\)\^5 + \(2\ \[Rho]\_2\ \[Tau]\_1\ \[Tau]\_2\)\/\((\
\[Tau]\_1 + \[Tau]\_2)\)\^5 - \(8\ \[Theta]e\_1\ \[Rho]\_2\ \[Tau]\_1\ \[Tau]\
\_2\)\/\((\[Tau]\_1 + \[Tau]\_2)\)\^5 + \(4\ \[Theta]e\_1\ \[Rho]\_1\ \
\[Tau]\_2\%2\)\/\((\[Tau]\_1 + \[Tau]\_2)\)\^5 - \(2\ \[Rho]\_2\ \[Tau]\_2\%2\
\)\/\((\[Tau]\_1 + \[Tau]\_2)\)\^5 - \(4\ \[Theta]e\_1\ \[Rho]\_2\ \
\[Tau]\_2\%2\)\/\((\[Tau]\_1 + \[Tau]\_2)\)\^5 - \(4\ \[Rho]\_1\%2\ \[Tau]\_1\
\ \[Tau]\_2\ \[Mu]\_\(2, 1\)\%2\)\/\(\((\[Tau]\_1 + \[Tau]\_2)\)\^5\ \
\[Mu]\_\(0, 2\)\) + \(8\ \[Rho]\_1\ \[Rho]\_2\ \[Tau]\_1\ \[Tau]\_2\ \
\[Mu]\_\(2, 1\)\%2\)\/\(\((\[Tau]\_1 + \[Tau]\_2)\)\^5\ \[Mu]\_\(0, 2\)\) - \
\(4\ \[Rho]\_2\%2\ \[Tau]\_1\ \[Tau]\_2\ \[Mu]\_\(2, 1\)\%2\)\/\(\((\[Tau]\_1 \
+ \[Tau]\_2)\)\^5\ \[Mu]\_\(0, 2\)\) - \(4\ \[Rho]\_1\%2\ \[Tau]\_1\ \
\[Tau]\_2\ \[Mu]\_\(3, 0\)\%2\)\/\((\[Tau]\_1 + \[Tau]\_2)\)\^5 + \(8\ \[Rho]\
\_1\ \[Rho]\_2\ \[Tau]\_1\ \[Tau]\_2\ \[Mu]\_\(3, 0\)\%2\)\/\((\[Tau]\_1 + \
\[Tau]\_2)\)\^5 - \(4\ \[Rho]\_2\%2\ \[Tau]\_1\ \[Tau]\_2\ \[Mu]\_\(3, 0\)\%2\
\)\/\((\[Tau]\_1 + \[Tau]\_2)\)\^5 - \(\[Kappa]\_1\ \[Tau]\_1\%2\ \[Mu]\_\(4, \
0\)\)\/\((\[Tau]\_1 + \[Tau]\_2)\)\^5 - \(\[Kappa]\_1\ \[Tau]\_1\ \[Tau]\_2\ \
\[Mu]\_\(4, 0\)\)\/\((\[Tau]\_1 + \[Tau]\_2)\)\^5 - \(\[Kappa]\_2\ \[Tau]\_1\ \
\[Tau]\_2\ \[Mu]\_\(4, 0\)\)\/\((\[Tau]\_1 + \[Tau]\_2)\)\^5 - \(\[Kappa]\_2\ \
\[Tau]\_2\%2\ \[Mu]\_\(4, 0\)\)\/\((\[Tau]\_1 + \[Tau]\_2)\)\^5\)], "Output"]
}, Open  ]],

Cell["Define the price function", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(PriceZ[\[Epsilon]_]\  = \ 
      1\  - \[Epsilon]\^2\ \ \[CapitalPi][\[Epsilon]]\)], "Input"],

Cell[BoxData[
    \(1 - \[Epsilon]\^2\ \[CapitalPi][\[Epsilon]]\)], "Output"]
}, Open  ]],

Cell["Compute the Taylor series for the price function", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TaylorPriceZ = \ 
      Normal[Series[PriceZ[\[Epsilon]]\ , {\[Epsilon], 0, 4}]]\)], "Input"],

Cell[BoxData[
    RowBox[{"1", "-", \(\[Epsilon]\^2\ \[CapitalPi][0]\), "-", 
      RowBox[{\(\[Epsilon]\^3\), " ", 
        RowBox[{
          SuperscriptBox["\[CapitalPi]", "\[Prime]",
            MultilineFunction->None], "[", "0", "]"}]}], "-", 
      RowBox[{\(1\/2\), " ", \(\[Epsilon]\^4\), " ", 
        RowBox[{
          SuperscriptBox["\[CapitalPi]", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "0", "]"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "TaylorPriceTwoAssetZ is the second-order expansion for the price of ",
  Cell[BoxData[
      \(TraditionalForm\`Z\)]],
  " when there are two assets."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TaylorPriceTwoAssetZ = \(\(\(\(TaylorPriceZ //. UtilParams\) /. Sol3\) /. 
              Sol2\) /. 
            BifPt\) /. {\[Theta]e\_2 \[Rule] \[CapitalTheta] - \[Theta]e\_1} // 
        Simplify\)], "Input"],

Cell[BoxData[
    \(1 - \[Epsilon]\^2\/\(\[Tau]\_1 + \[Tau]\_2\) + \(\[Epsilon]\^3\ \((\
\[Rho]\_1\ \[Tau]\_1 + \[Rho]\_2\ \[Tau]\_2)\)\ \[Mu]\_\(3, \
0\)\)\/\((\[Tau]\_1 + \[Tau]\_2)\)\^3 + \(\(1\/\(2\ \((\[Tau]\_1 + \[Tau]\_2)\
\)\^5\ \[Mu]\_\(0, 2\)\)\)\((\[Epsilon]\^4\ \((2\ \[Rho]\_2\ \((\[Tau]\_1 + \
\[Tau]\_2)\)\ \((2\ \((\(-1\) + \[Theta]e\_1)\)\ \[Tau]\_1 + \((1 + 
                          2\ \[Theta]e\_1)\)\ \[Tau]\_2)\)\ \[Mu]\_\(0, 2\) + 
              4\ \[Rho]\_1\%2\ \[Tau]\_1\ \[Tau]\_2\ \((\[Mu]\_\(2, 1\)\%2 + \
\[Mu]\_\(0, 2\)\ \[Mu]\_\(3, 0\)\%2)\) + 
              4\ \[Rho]\_2\%2\ \[Tau]\_1\ \[Tau]\_2\ \((\[Mu]\_\(2, 1\)\%2 + \
\[Mu]\_\(0, 2\)\ \[Mu]\_\(3, 0\)\%2)\) - 
              2\ \[Rho]\_1\ \((\((\(-3\) + 
                          2\ \[Theta]e\_1)\)\ \[Tau]\_1\%2\ \[Mu]\_\(0, 2\) + 
                    2\ \[Theta]e\_1\ \[Tau]\_2\%2\ \[Mu]\_\(0, 2\) + \
\[Tau]\_1\ \[Tau]\_2\ \((4\ \[Rho]\_2\ \[Mu]\_\(2, 1\)\%2 + \[Mu]\_\(0, 2\)\ \
\((\(-3\) + 4\ \[Theta]e\_1 + 
                                4\ \[Rho]\_2\ \[Mu]\_\(3, 0\)\%2)\))\))\) + \
\((\[Tau]\_1 + \[Tau]\_2)\)\ \((\[Kappa]\_1\ \[Tau]\_1 + \[Kappa]\_2\ \
\[Tau]\_2)\)\ \[Mu]\_\(0, 2\)\ \[Mu]\_\(4, 0\))\))\)\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "TaylorPriceOneAssetZ is the second-order expansion for the price of Z when \
there is just Z. It equals TaylorPriceTwoAssetZ with the moments for ",
  Cell[BoxData[
      \(TraditionalForm\`Y\)]],
  " and cross-moments between ",
  Cell[BoxData[
      \(TraditionalForm\`Z\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`Y\)]],
  " zeroed out by the substitutions in NoDeriv."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TaylorPriceOneAssetZ = 
      TaylorPriceTwoAssetZ //. NoDeriv // Simplify\)], "Input"],

Cell[BoxData[
    \(1 - \[Epsilon]\^2\/\(\[Tau]\_1 + \[Tau]\_2\) + \(\[Epsilon]\^3\ \((\
\[Rho]\_1\ \[Tau]\_1 + \[Rho]\_2\ \[Tau]\_2)\)\ \[Mu]\_\(3, \
0\)\)\/\((\[Tau]\_1 + \[Tau]\_2)\)\^3 + \(\(1\/\(2\ \((\[Tau]\_1 + \[Tau]\_2)\
\)\^5\)\)\((\[Epsilon]\^4\ \((2\ \[Rho]\_2\ \((\[Tau]\_1 + \[Tau]\_2)\)\ \((2\
\ \((\(-1\) + \[Theta]e\_1)\)\ \[Tau]\_1 + \((1 + 
                          2\ \[Theta]e\_1)\)\ \[Tau]\_2)\) + 
              4\ \[Rho]\_1\%2\ \[Tau]\_1\ \[Tau]\_2\ \[Mu]\_\(3, 0\)\%2 + 
              4\ \[Rho]\_2\%2\ \[Tau]\_1\ \[Tau]\_2\ \[Mu]\_\(3, 0\)\%2 - 
              2\ \[Rho]\_1\ \((\((\(-3\) + 2\ \[Theta]e\_1)\)\ \[Tau]\_1\%2 + 
                    2\ \[Theta]e\_1\ \[Tau]\_2\%2 + \[Tau]\_1\ \[Tau]\_2\ \((\
\(-3\) + 4\ \[Theta]e\_1 + 
                          4\ \[Rho]\_2\ \[Mu]\_\(3, 0\)\%2)\))\) + \
\((\[Tau]\_1 + \[Tau]\_2)\)\ \((\[Kappa]\_1\ \[Tau]\_1 + \[Kappa]\_2\ \
\[Tau]\_2)\)\ \[Mu]\_\(4, 0\))\))\)\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "We now compute the difference to determine the impact of the derivative \
asset on the price of ",
  Cell[BoxData[
      \(TraditionalForm\`Z\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(TaylorPriceTwoAssetZ - TaylorPriceOneAssetZ // Together\) // 
      Simplify\)], "Input"],

Cell[BoxData[
    \(\(2\ \[Epsilon]\^4\ \((\[Rho]\_1 - \[Rho]\_2)\)\^2\ \[Tau]\_1\ \
\[Tau]\_2\ \[Mu]\_\(2, 1\)\%2\)\/\(\((\[Tau]\_1 + \[Tau]\_2)\)\^5\ \
\[Mu]\_\(0, 2\)\)\)], "Output"]
}, Open  ]],

Cell["This is the result in Theorem 11.", "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Equation 5:", "Subsection"],

Cell[TextData[{
  "We next compute (\[Theta]'''[0],",
  "\[Phi]",
  "'''[0],\[CapitalPsi]'''[0],\[CapitalPi]'''[0]) by setting the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\^4\)]],
  " components equal to zero. We do this since these third derivatives may \
play a role in the utility analysis below."
}], "Text"],

Cell[BoxData[{
    \(\(Eq1\  = \ \(\(\(\(Eqns11[\([5]\)] //. UtilParams\) /. Sol3\) /. 
              Sol2\) /. 
            BifPt\) /. {\[Theta]e\_2 \[Rule] \[CapitalTheta] - \[Theta]e\_1};\
\)\), "\n", 
    \(\(Eq2\  = \ \(\(\(\(Eqns21[\([5]\)] //. UtilParams\) /. Sol3\) /. 
              Sol2\) /. 
            BifPt\) /. {\[Theta]e\_2 \[Rule] \[CapitalTheta] - \[Theta]e\_1};\
\)\), "\n", 
    \(\(Eq3\  = \ \(\(\(\(Eqns12[\([5]\)] //. UtilParams\) /. Sol3\) /. 
              Sol2\) /. 
            BifPt\) /. {\[Theta]e\_2 \[Rule] \[CapitalTheta] - \[Theta]e\_1};\
\)\), "\n", 
    \(\(Eq4\  = \ \(\(\(\(Eqns22[\([5]\)] //. UtilParams\) /. Sol3\) /. 
              Sol2\) /. 
            BifPt\) /. {\[Theta]e\_2 \[Rule] \[CapitalTheta] - \[Theta]e\_1};\
\)\)}], "Input"],

Cell["We display the first equation as an example", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Eq1 // Simplify\)], "Input"],

Cell[BoxData[
    RowBox[{\(1\/\(24\ \[Tau]\_1\ \((\[Tau]\_1 + \[Tau]\_2)\)\^6\ \[Mu]\_\(0, \
2\)\%2\)\), 
      RowBox[{"(", 
        RowBox[{\(120\ \[Rho]\_1\%3\ \[Tau]\_1\ \[Tau]\_2\%2\ \((\[Mu]\_\(1, \
2\)\ \[Mu]\_\(2, 1\)\%2 + \[Mu]\_\(0, 2\)\ \[Mu]\_\(3, 0\)\ \((2\ \[Mu]\_\(2, \
1\)\%2 + \[Mu]\_\(0, 2\)\ \[Mu]\_\(3, 0\)\%2)\))\)\), 
          "+", \(24\ \[Rho]\_1\%2\ \((\((\[Tau]\_1 + \[Tau]\_2)\)\ \((\((\(-3\
\) + 2\ \[Theta]e\_1)\)\ \[Tau]\_1\%2 - 
                      4\ \((\(-3\) + \[Theta]e\_1)\)\ \[Tau]\_1\ \[Tau]\_2 - 
                      6\ \[Theta]e\_1\ \[Tau]\_2\%2)\)\ \[Mu]\_\(0, 2\)\%2\ \
\[Mu]\_\(3, 0\) + 
                2\ \[Rho]\_2\ \[Tau]\_1\ \((2\ \[Tau]\_1 - 
                      3\ \[Tau]\_2)\)\ \[Tau]\_2\ \((\[Mu]\_\(1, 2\)\ \[Mu]\_\
\(2, 1\)\%2 + \[Mu]\_\(0, 2\)\ \[Mu]\_\(3, 0\)\ \((2\ \[Mu]\_\(2, 1\)\%2 + \
\[Mu]\_\(0, 2\)\ \[Mu]\_\(3, 0\)\%2)\))\))\)\), 
          "-", \(12\ \[Rho]\_1\ \((2\ \[Rho]\_2\ \((\[Tau]\_1 + \[Tau]\_2)\)\ \
\((4\ \((\(-1\) + \[Theta]e\_1)\)\ \[Tau]\_1\%2 + 11\ \[Tau]\_1\ \[Tau]\_2 - 
                      4\ \[Theta]e\_1\ \[Tau]\_2\%2)\)\ \[Mu]\_\(0, 2\)\%2\ \
\[Mu]\_\(3, 0\) + 
                2\ \[Rho]\_2\%2\ \[Tau]\_1\ \((4\ \[Tau]\_1 - \[Tau]\_2)\)\ \
\[Tau]\_2\ \((\[Mu]\_\(1, 2\)\ \[Mu]\_\(2, 1\)\%2 + \[Mu]\_\(0, 2\)\ \
\[Mu]\_\(3, 0\)\ \((2\ \[Mu]\_\(2, 1\)\%2 + \[Mu]\_\(0, 2\)\ \[Mu]\_\(3, \
0\)\%2)\))\) - \[Tau]\_2\ \((\[Tau]\_1 + \[Tau]\_2)\)\ \[Mu]\_\(0, 2\)\ \((4\ \
\[Theta]e\_1\ \[Tau]\_2\ \[Mu]\_\(0, 2\)\ \[Mu]\_\(3, 0\) + \[Tau]\_1\ \
\((\((5\ \[Kappa]\_1 - 
                                  2\ \[Kappa]\_2)\)\ \[Mu]\_\(2, 1\)\ \[Mu]\_\
\(3, 1\) + \[Mu]\_\(0, 2\)\ \[Mu]\_\(3, 0\)\ \((\(-6\) + 4\ \[Theta]e\_1 + 
                                  5\ \[Kappa]\_1\ \[Mu]\_\(4, 0\) - 
                                  2\ \[Kappa]\_2\ \[Mu]\_\(4, 0\))\))\))\))\)\
\), "-", 
          
          RowBox[{\((\[Tau]\_1 + \[Tau]\_2)\), " ", \(\[Mu]\_\(0, 2\)\), " ", 
            
            RowBox[{"(", 
              
              RowBox[{\(12\ \[Kappa]\_1\ \((\((\(-4\) + 
                            3\ \[Theta]e\_1)\)\ \[Tau]\_1\%2\ \[Mu]\_\(0, 2\)\
\ \[Mu]\_\(3, 0\) + 
                      3\ \[Theta]e\_1\ \[Tau]\_2\%2\ \[Mu]\_\(0, 2\)\ \[Mu]\_\
\(3, 0\) + \[Tau]\_1\ \[Tau]\_2\ \((3\ \[Rho]\_2\ \[Mu]\_\(2, 1\)\ \
\[Mu]\_\(3, 1\) + \[Mu]\_\(0, 2\)\ \[Mu]\_\(3, 0\)\ \((\(-4\) + 
                                  6\ \[Theta]e\_1 + 
                                  3\ \[Rho]\_2\ \[Mu]\_\(4, 0\))\))\))\)\), 
                "+", 
                RowBox[{\(\[Mu]\_\(0, 2\)\), " ", 
                  RowBox[{"(", 
                    
                    RowBox[{\(24\ \[Rho]\_2\ \[Tau]\_2\ \((\((\(-3\) + 
                                  2\ \[Theta]e\_1)\)\ \[Tau]\_1 + 
                            2\ \[Theta]e\_1\ \[Tau]\_2)\)\ \[Mu]\_\(3, 0\)\), 
                      "-", 
                      RowBox[{\((\[Tau]\_1 + \[Tau]\_2)\), " ", 
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{\(\[Tau]\_1\%5\), " ", 
                              RowBox[{"(", 
                                RowBox[{\(\[Mu]\_\(5, 0\)\ A\_1[5]\), "+", 
                                  RowBox[{"4", " ", 
                                    RowBox[{
                                      SuperscriptBox["\[CapitalPi]", 
                                        TagBox[\((3)\),
                                        Derivative],
                                        MultilineFunction->None], "[", "0", 
                                      "]"}]}]}], ")"}]}], "-", 
                            RowBox[{"4", " ", \(\[Tau]\_2\%4\), " ", 
                              RowBox[{"(", 
                                RowBox[{
                                  RowBox[{
                                    SuperscriptBox["\[Theta]", 
                                      TagBox[\((3)\),
                                        Derivative],
                                      MultilineFunction->None], "[", "0", 
                                    "]"}], "+", 
                                  RowBox[{"\[Alpha]", " ", 
                                    RowBox[{
                                      SuperscriptBox["\[Phi]", 
                                        TagBox[\((3)\),
                                        Derivative],
                                        MultilineFunction->None], "[", "0", 
                                      "]"}]}]}], ")"}]}], "-", 
                            RowBox[{"4", " ", \(\[Tau]\_1\%4\), " ", 
                              RowBox[{"(", 
                                RowBox[{
                                  RowBox[{
                                    SuperscriptBox["\[Theta]", 
                                      TagBox[\((3)\),
                                        Derivative],
                                      MultilineFunction->None], "[", "0", 
                                    "]"}], "-", 
                                  RowBox[{"4", " ", \(\[Tau]\_2\), " ", 
                                    RowBox[{
                                      SuperscriptBox["\[CapitalPi]", 
                                        TagBox[\((3)\),
                                        Derivative],
                                        MultilineFunction->None], "[", "0", 
                                      "]"}]}], "+", 
                                  RowBox[{"\[Alpha]", " ", 
                                    RowBox[{
                                      SuperscriptBox["\[Phi]", 
                                        TagBox[\((3)\),
                                        Derivative],
                                        MultilineFunction->None], "[", "0", 
                                      "]"}]}]}], ")"}]}], "+", 
                            RowBox[{
                            "4", " ", \(\[Tau]\_1\), " ", \(\[Tau]\_2\%3\), 
                              " ", 
                              RowBox[{"(", 
                                RowBox[{
                                  RowBox[{\(\[Tau]\_2\), " ", 
                                    RowBox[{
                                      SuperscriptBox["\[CapitalPi]", 
                                        TagBox[\((3)\),
                                        Derivative],
                                        MultilineFunction->None], "[", "0", 
                                      "]"}]}], "-", 
                                  RowBox[{"4", " ", 
                                    RowBox[{"(", 
                                      RowBox[{
                                        RowBox[{
                                        SuperscriptBox["\[Theta]", 
                                        TagBox[\((3)\),
                                        Derivative],
                                        MultilineFunction->None], "[", "0", 
                                        "]"}], "+", 
                                        RowBox[{"\[Alpha]", " ", 
                                        RowBox[{
                                        SuperscriptBox["\[Phi]", 
                                        TagBox[\((3)\),
                                        Derivative],
                                        MultilineFunction->None], "[", "0", 
                                        "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
                            RowBox[{
                            "8", " ", \(\[Tau]\_1\%2\), " ", \(\[Tau]\_2\%2\),
                               " ", 
                              RowBox[{"(", 
                                RowBox[{
                                  RowBox[{"2", " ", \(\[Tau]\_2\), " ", 
                                    RowBox[{
                                      SuperscriptBox["\[CapitalPi]", 
                                        TagBox[\((3)\),
                                        Derivative],
                                        MultilineFunction->None], "[", "0", 
                                      "]"}]}], "-", 
                                  RowBox[{"3", " ", 
                                    RowBox[{"(", 
                                      RowBox[{
                                        RowBox[{
                                        SuperscriptBox["\[Theta]", 
                                        TagBox[\((3)\),
                                        Derivative],
                                        MultilineFunction->None], "[", "0", 
                                        "]"}], "+", 
                                        RowBox[{"\[Alpha]", " ", 
                                        RowBox[{
                                        SuperscriptBox["\[Phi]", 
                                        TagBox[\((3)\),
                                        Derivative],
                                        MultilineFunction->None], "[", "0", 
                                        "]"}]}]}], ")"}]}]}], ")"}]}], "+", 
                            RowBox[{
                            "8", " ", \(\[Tau]\_1\%3\), " ", \(\[Tau]\_2\), 
                              " ", 
                              RowBox[{"(", 
                                RowBox[{
                                  RowBox[{"3", " ", \(\[Tau]\_2\), " ", 
                                    RowBox[{
                                      SuperscriptBox["\[CapitalPi]", 
                                        TagBox[\((3)\),
                                        Derivative],
                                        MultilineFunction->None], "[", "0", 
                                      "]"}]}], "-", 
                                  RowBox[{"2", " ", 
                                    RowBox[{"(", 
                                      RowBox[{
                                        RowBox[{
                                        SuperscriptBox["\[Theta]", 
                                        TagBox[\((3)\),
                                        Derivative],
                                        MultilineFunction->None], "[", "0", 
                                        "]"}], "+", 
                                        RowBox[{"\[Alpha]", " ", 
                                        RowBox[{
                                        SuperscriptBox["\[Phi]", 
                                        TagBox[\((3)\),
                                        Derivative],
                                        MultilineFunction->None], "[", "0", 
                                        "]"}]}]}], ")"}]}]}], ")"}]}]}], 
                          ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]], "Output"]
}, Open  ]],

Cell["\<\
We now solve for the third derivatives. We do not display any of the results \
since they are very long and difficult to interpret.\
\>", "Text"],

Cell[BoxData[
    \(\(Sol4\  = \ \(Solve[{Eq1 \[Equal] 0, \ Eq2 \[Equal] 0, \ 
              Eq3 \[Equal] 0, \ 
              Eq4 \[Equal] 0}, {\ \(\(\(\[Theta]'\)'\)'\)[0], \(\[Phi]'''\)[
                0], \(\(\(\[CapitalPsi]'\)'\)'\)[
                0], \(\(\(\[CapitalPi]'\)'\)'\)[0]}]\)[\([1]\)];\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Utility Expansion", "Subtitle"],

Cell[TextData[{
  "We want to evaluate the impact of the derivative security ",
  Cell[BoxData[
      \(TraditionalForm\`Y\)]],
  " on utility. This is necessary to derive the results in Section 6.4."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Utility\)], "Section",
  FontFamily->"Arial"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`W\_1\)]],
  " is the final wealth and consumption of a type 1 agent. Express it in \
terms of the random variables ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  ", and portfolio holdings."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(W\_1 = Expand[W\_1]\)], "Input"],

Cell[BoxData[
    \(z\ \[Epsilon]\ \[Theta] + \[Epsilon]\^2\ \[Theta]\ \[CapitalPi] + 
      y\ \[Epsilon]\ \[Phi] + 
      z\ \[Alpha]\ \[Epsilon]\ \[Phi] + \[Epsilon]\^2\ \[Phi]\ \[CapitalPsi] \
+ Be\_1 + \[Theta]e\_1 - \[Epsilon]\^2\ \[CapitalPi]\ \[Theta]e\_1\)], \
"Output"]
}, Open  ]],

Cell["\<\
Define equilibrium expected utility for type 1 agents by substituting the \
equilibrium functions for \[Theta], \[Phi], \[CapitalPi], and \[CapitalPsi] \
into our expression for final consumption. The result is equilibrium utility \
as a function of \[Epsilon].\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(U1 = \(u\_1[W\_1] /. PortfolioSubs\) /. PremiaSubs\)], "Input"],

Cell[BoxData[
    \(u\_1[
      Be\_1 + \[Theta]e\_1 + 
        z\ \[Epsilon]\ \[Theta][\[Epsilon]] - \[Epsilon]\^2\ \[Theta]e\_1\ \
\[CapitalPi][\[Epsilon]] + \[Epsilon]\^2\ \[Theta][\[Epsilon]]\ \[CapitalPi][\
\[Epsilon]] + y\ \[Epsilon]\ \[Phi][\[Epsilon]] + 
        z\ \[Alpha]\ \[Epsilon]\ \[Phi][\[Epsilon]] + \[Epsilon]\^2\ \[Phi][\
\[Epsilon]]\ \[CapitalPsi][\[Epsilon]]]\)], "Output"]
}, Open  ]],

Cell["\<\
Compute the degree 5 Taylor series of the utility of type 1 agents in terms \
of \[Epsilon] and call it U1pow.\
\>", "Text"],

Cell[BoxData[
    \(\(U1pow = 
        Normal[Series[U1\ , {\[Epsilon], 0, 5}]] //. UtilDerivs;\)\)], "Input"],

Cell[TextData[{
  "Expand it so that products of ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " are collected"
}], "Text"],

Cell[BoxData[
    \(\(U1pow\  = \ Expand[U1pow];\)\)], "Input"],

Cell[TextData[{
  "Compute expected utility by replacing instances of powers of ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " with their moment expressions"
}], "Text"],

Cell[BoxData[
    \(\(U1pow\  = \ U1pow //. moments;\)\)], "Input"],

Cell["\<\
Replace \[Theta], \[Phi], \[CapitalPi], and \[CapitalPsi] and their \
derivatives with the solutions derived above.\
\>", "Text"],

Cell[BoxData[
    \(\(U1pow\  = \ \(\(\(\(U1pow /. Sol4\) /. Sol3\) /. Sol2\) /. BifPt\) //. 
          UtilDerivs;\)\)], "Input"],

Cell["\<\
Express in terms of \[Tau], \[Rho], and \[Kappa].\
\>", "Text"],

Cell[BoxData[
    \(\(U1pow\  = \ U1pow //. UtilParams;\)\)], "Input"],

Cell["\<\
Combine like powers of \[Epsilon] and put the coefficients in the list U1\
\[Epsilon]pows.\
\>", "Text"],

Cell[BoxData[
    \(\(U1\[Epsilon]pows\  = \ 
        CoefficientList[U1pow, \[Epsilon]];\)\)], "Input"],

Cell[TextData[{
  "Display the coefficients of 1, \[Epsilon], ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\^2\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\^3\)]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[U1\[Epsilon]pows[\([i]\)], {i, 1, 4}] // Simplify\)], "Input"],

Cell[BoxData[
    \({u\_1[Be\_1 + \[Theta]e\_1], 
      0, \(\[Tau]\_1 - 2\ \[Theta]e\_1\ \((\[Tau]\_1 + \[Tau]\_2)\)\)\/\(2\ \
\((\[Tau]\_1 + \[Tau]\_2)\)\^2\), \(\((3\ \[Rho]\_2\ \[Tau]\_2\ \((\((\(-1\) \
+ \[Theta]e\_1)\)\ \[Tau]\_1 + \[Theta]e\_1\ \[Tau]\_2)\) + \[Rho]\_1\ \[Tau]\
\_1\ \((\((\(-2\) + 3\ \[Theta]e\_1)\)\ \[Tau]\_1 + \((1 + 3\ \[Theta]e\_1)\)\
\ \[Tau]\_2)\))\)\ \[Mu]\_\(3, 0\)\)\/\(3\ \((\[Tau]\_1 + \
\[Tau]\_2)\)\^4\)}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This list shows that the moments of ",
  Cell[BoxData[
      \(TraditionalForm\`Y\)]],
  " and its cross-moments with ",
  Cell[BoxData[
      \(TraditionalForm\`Z\)]],
  " have no impact on utility up to the order ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\^3\)]],
  ". Therefore, we move to the fourth-order terms to determine the utility \
impact of the derivative security."
}], "Text"],

Cell[CellGroupData[{

Cell["Utility difference - order 4", "Subsection"],

Cell[TextData[{
  "Compute the utility contribution of the new asset. The utility difference \
is the utility with a nontrivial ",
  Cell[BoxData[
      \(TraditionalForm\`Y\)]],
  " minus the utility with trivial ",
  Cell[BoxData[
      \(TraditionalForm\`Y\)]],
  ", that is, a ",
  Cell[BoxData[
      \(TraditionalForm\`Y\)]],
  " with zero co-moments with z."
}], "Text"],

Cell["\<\
Util4 is the degree four term in the utility expansion with two assets and \
equals\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Util4\  = \ U1\[Epsilon]pows[\([5]\)] // Together\)], "Input"],

Cell[BoxData[
    \(\(\(1\/\(8\ \[Tau]\_1\ \((\[Tau]\_1 + \[Tau]\_2)\)\^6\ \[Mu]\_\(0, \
2\)\)\)\((\(-4\)\ \[Tau]\_1\%4\ \[Mu]\_\(0, 2\) + 
        8\ \[Theta]e\_1\ \[Tau]\_1\%4\ \[Mu]\_\(0, 2\) - 
        4\ \[Theta]e\_1\%2\ \[Tau]\_1\%4\ \[Mu]\_\(0, 2\) - 
        16\ \[Rho]\_1\ \[Tau]\_1\%4\ \[Mu]\_\(0, 2\) + 
        32\ \[Theta]e\_1\ \[Rho]\_1\ \[Tau]\_1\%4\ \[Mu]\_\(0, 2\) - 
        16\ \[Theta]e\_1\%2\ \[Rho]\_1\ \[Tau]\_1\%4\ \[Mu]\_\(0, 2\) + 
        16\ \[Rho]\_2\ \[Tau]\_1\%4\ \[Mu]\_\(0, 2\) - 
        32\ \[Theta]e\_1\ \[Rho]\_2\ \[Tau]\_1\%4\ \[Mu]\_\(0, 2\) + 
        16\ \[Theta]e\_1\%2\ \[Rho]\_2\ \[Tau]\_1\%4\ \[Mu]\_\(0, 2\) - 
        8\ \[Tau]\_1\%3\ \[Tau]\_2\ \[Mu]\_\(0, 2\) + 
        24\ \[Theta]e\_1\ \[Tau]\_1\%3\ \[Tau]\_2\ \[Mu]\_\(0, 2\) - 
        16\ \[Theta]e\_1\%2\ \[Tau]\_1\%3\ \[Tau]\_2\ \[Mu]\_\(0, 2\) - 
        8\ \[Rho]\_1\ \[Tau]\_1\%3\ \[Tau]\_2\ \[Mu]\_\(0, 2\) + 
        56\ \[Theta]e\_1\ \[Rho]\_1\ \[Tau]\_1\%3\ \[Tau]\_2\ \[Mu]\_\(0, 2\) \
- 48\ \[Theta]e\_1\%2\ \[Rho]\_1\ \[Tau]\_1\%3\ \[Tau]\_2\ \[Mu]\_\(0, 2\) + 
        8\ \[Rho]\_2\ \[Tau]\_1\%3\ \[Tau]\_2\ \[Mu]\_\(0, 2\) - 
        56\ \[Theta]e\_1\ \[Rho]\_2\ \[Tau]\_1\%3\ \[Tau]\_2\ \[Mu]\_\(0, 2\) \
+ 48\ \[Theta]e\_1\%2\ \[Rho]\_2\ \[Tau]\_1\%3\ \[Tau]\_2\ \[Mu]\_\(0, 2\) - 
        4\ \[Tau]\_1\%2\ \[Tau]\_2\%2\ \[Mu]\_\(0, 2\) + 
        24\ \[Theta]e\_1\ \[Tau]\_1\%2\ \[Tau]\_2\%2\ \[Mu]\_\(0, 2\) - 
        24\ \[Theta]e\_1\%2\ \[Tau]\_1\%2\ \[Tau]\_2\%2\ \[Mu]\_\(0, 2\) + 
        8\ \[Rho]\_1\ \[Tau]\_1\%2\ \[Tau]\_2\%2\ \[Mu]\_\(0, 2\) + 
        16\ \[Theta]e\_1\ \[Rho]\_1\ \[Tau]\_1\%2\ \[Tau]\_2\%2\ \[Mu]\_\(0, \
2\) - 48\ \[Theta]e\_1\%2\ \[Rho]\_1\ \[Tau]\_1\%2\ \[Tau]\_2\%2\ \[Mu]\_\(0, \
2\) - 8\ \[Rho]\_2\ \[Tau]\_1\%2\ \[Tau]\_2\%2\ \[Mu]\_\(0, 2\) - 
        16\ \[Theta]e\_1\ \[Rho]\_2\ \[Tau]\_1\%2\ \[Tau]\_2\%2\ \[Mu]\_\(0, \
2\) + 48\ \[Theta]e\_1\%2\ \[Rho]\_2\ \[Tau]\_1\%2\ \[Tau]\_2\%2\ \[Mu]\_\(0, \
2\) + 8\ \[Theta]e\_1\ \[Tau]\_1\ \[Tau]\_2\%3\ \[Mu]\_\(0, 2\) - 
        16\ \[Theta]e\_1\%2\ \[Tau]\_1\ \[Tau]\_2\%3\ \[Mu]\_\(0, 2\) - 
        8\ \[Theta]e\_1\ \[Rho]\_1\ \[Tau]\_1\ \[Tau]\_2\%3\ \[Mu]\_\(0, 2\) \
- 16\ \[Theta]e\_1\%2\ \[Rho]\_1\ \[Tau]\_1\ \[Tau]\_2\%3\ \[Mu]\_\(0, 2\) + 
        8\ \[Theta]e\_1\ \[Rho]\_2\ \[Tau]\_1\ \[Tau]\_2\%3\ \[Mu]\_\(0, 2\) \
+ 16\ \[Theta]e\_1\%2\ \[Rho]\_2\ \[Tau]\_1\ \[Tau]\_2\%3\ \[Mu]\_\(0, 2\) - 
        4\ \[Theta]e\_1\%2\ \[Tau]\_2\%4\ \[Mu]\_\(0, 2\) - 
        16\ \[Rho]\_1\%2\ \[Tau]\_1\%3\ \[Tau]\_2\ \[Mu]\_\(2, 1\)\%2 + 
        16\ \[Theta]e\_1\ \[Rho]\_1\%2\ \[Tau]\_1\%3\ \[Tau]\_2\ \[Mu]\_\(2, \
1\)\%2 + 32\ \[Rho]\_1\ \[Rho]\_2\ \[Tau]\_1\%3\ \[Tau]\_2\ \[Mu]\_\(2, \
1\)\%2 - 32\ \[Theta]e\_1\ \[Rho]\_1\ \[Rho]\_2\ \[Tau]\_1\%3\ \[Tau]\_2\ \
\[Mu]\_\(2, 1\)\%2 - 
        16\ \[Rho]\_2\%2\ \[Tau]\_1\%3\ \[Tau]\_2\ \[Mu]\_\(2, 1\)\%2 + 
        16\ \[Theta]e\_1\ \[Rho]\_2\%2\ \[Tau]\_1\%3\ \[Tau]\_2\ \[Mu]\_\(2, \
1\)\%2 + 4\ \[Rho]\_1\%2\ \[Tau]\_1\%2\ \[Tau]\_2\%2\ \[Mu]\_\(2, 1\)\%2 + 
        16\ \[Theta]e\_1\ \[Rho]\_1\%2\ \[Tau]\_1\%2\ \[Tau]\_2\%2\ \
\[Mu]\_\(2, 1\)\%2 - 
        8\ \[Rho]\_1\ \[Rho]\_2\ \[Tau]\_1\%2\ \[Tau]\_2\%2\ \[Mu]\_\(2, \
1\)\%2 - 32\ \[Theta]e\_1\ \[Rho]\_1\ \[Rho]\_2\ \[Tau]\_1\%2\ \[Tau]\_2\%2\ \
\[Mu]\_\(2, 1\)\%2 + 
        4\ \[Rho]\_2\%2\ \[Tau]\_1\%2\ \[Tau]\_2\%2\ \[Mu]\_\(2, 1\)\%2 + 
        16\ \[Theta]e\_1\ \[Rho]\_2\%2\ \[Tau]\_1\%2\ \[Tau]\_2\%2\ \
\[Mu]\_\(2, 1\)\%2 - 
        16\ \[Rho]\_1\%2\ \[Tau]\_1\%3\ \[Tau]\_2\ \[Mu]\_\(0, 2\)\ \
\[Mu]\_\(3, 0\)\%2 + 
        16\ \[Theta]e\_1\ \[Rho]\_1\%2\ \[Tau]\_1\%3\ \[Tau]\_2\ \[Mu]\_\(0, \
2\)\ \[Mu]\_\(3, 0\)\%2 + 
        32\ \[Rho]\_1\ \[Rho]\_2\ \[Tau]\_1\%3\ \[Tau]\_2\ \[Mu]\_\(0, 2\)\ \
\[Mu]\_\(3, 0\)\%2 - 
        32\ \[Theta]e\_1\ \[Rho]\_1\ \[Rho]\_2\ \[Tau]\_1\%3\ \[Tau]\_2\ \
\[Mu]\_\(0, 2\)\ \[Mu]\_\(3, 0\)\%2 - 
        16\ \[Rho]\_2\%2\ \[Tau]\_1\%3\ \[Tau]\_2\ \[Mu]\_\(0, 2\)\ \
\[Mu]\_\(3, 0\)\%2 + 
        16\ \[Theta]e\_1\ \[Rho]\_2\%2\ \[Tau]\_1\%3\ \[Tau]\_2\ \[Mu]\_\(0, \
2\)\ \[Mu]\_\(3, 0\)\%2 + 
        4\ \[Rho]\_1\%2\ \[Tau]\_1\%2\ \[Tau]\_2\%2\ \[Mu]\_\(0, 2\)\ \[Mu]\_\
\(3, 0\)\%2 + 
        16\ \[Theta]e\_1\ \[Rho]\_1\%2\ \[Tau]\_1\%2\ \[Tau]\_2\%2\ \
\[Mu]\_\(0, 2\)\ \[Mu]\_\(3, 0\)\%2 - 
        8\ \[Rho]\_1\ \[Rho]\_2\ \[Tau]\_1\%2\ \[Tau]\_2\%2\ \[Mu]\_\(0, 2\)\ \
\[Mu]\_\(3, 0\)\%2 - 
        32\ \[Theta]e\_1\ \[Rho]\_1\ \[Rho]\_2\ \[Tau]\_1\%2\ \[Tau]\_2\%2\ \
\[Mu]\_\(0, 2\)\ \[Mu]\_\(3, 0\)\%2 + 
        4\ \[Rho]\_2\%2\ \[Tau]\_1\%2\ \[Tau]\_2\%2\ \[Mu]\_\(0, 2\)\ \[Mu]\_\
\(3, 0\)\%2 + 
        16\ \[Theta]e\_1\ \[Rho]\_2\%2\ \[Tau]\_1\%2\ \[Tau]\_2\%2\ \
\[Mu]\_\(0, 2\)\ \[Mu]\_\(3, 0\)\%2 - 
        3\ \[Kappa]\_1\ \[Tau]\_1\%4\ \[Mu]\_\(0, 2\)\ \[Mu]\_\(4, 0\) + 
        4\ \[Theta]e\_1\ \[Kappa]\_1\ \[Tau]\_1\%4\ \[Mu]\_\(0, 2\)\ \
\[Mu]\_\(4, 0\) - 
        2\ \[Kappa]\_1\ \[Tau]\_1\%3\ \[Tau]\_2\ \[Mu]\_\(0, 2\)\ \[Mu]\_\(4, \
0\) + 8\ \[Theta]e\_1\ \[Kappa]\_1\ \[Tau]\_1\%3\ \[Tau]\_2\ \[Mu]\_\(0, 2\)\ \
\[Mu]\_\(4, 0\) - 
        4\ \[Kappa]\_2\ \[Tau]\_1\%3\ \[Tau]\_2\ \[Mu]\_\(0, 2\)\ \[Mu]\_\(4, \
0\) + 4\ \[Theta]e\_1\ \[Kappa]\_2\ \[Tau]\_1\%3\ \[Tau]\_2\ \[Mu]\_\(0, 2\)\ \
\[Mu]\_\(4, 0\) + \[Kappa]\_1\ \[Tau]\_1\%2\ \[Tau]\_2\%2\ \[Mu]\_\(0, 2\)\ \
\[Mu]\_\(4, 0\) + 
        4\ \[Theta]e\_1\ \[Kappa]\_1\ \[Tau]\_1\%2\ \[Tau]\_2\%2\ \[Mu]\_\(0, \
2\)\ \[Mu]\_\(4, 0\) - 
        4\ \[Kappa]\_2\ \[Tau]\_1\%2\ \[Tau]\_2\%2\ \[Mu]\_\(0, 2\)\ \
\[Mu]\_\(4, 0\) + 
        8\ \[Theta]e\_1\ \[Kappa]\_2\ \[Tau]\_1\%2\ \[Tau]\_2\%2\ \[Mu]\_\(0, \
2\)\ \[Mu]\_\(4, 0\) + 
        4\ \[Theta]e\_1\ \[Kappa]\_2\ \[Tau]\_1\ \[Tau]\_2\%3\ \[Mu]\_\(0, \
2\)\ \[Mu]\_\(4, 0\))\)\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This term is very complex and difficult to interpret. However, since we \
are only interested in the impact of the new security on utility, we do not \
need to understand all of Util4. We only need to understand how the new \
security affects Util4. Examination of Util4 shows that ",
  Cell[BoxData[
      \(\[Mu]\_\(2, 1\)\)]],
  " is the only moment involving the new asset in the expression Util4. The \
degree four term in the utility expansion for the case with only one asset is \
computed by evaluating ",
  "Util4",
  " with ",
  Cell[BoxData[
      \(\[Mu]\_\(2, 1\)\)]],
  " set equal to zero."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((Util4 /. {\ \[Mu]\_\(2, 1\) -> 0})\)\)], "Input"],

Cell[BoxData[
    \(\(\(1\/\(8\ \[Tau]\_1\ \((\[Tau]\_1 + \[Tau]\_2)\)\^6\ \[Mu]\_\(0, \
2\)\)\)\((\(-4\)\ \[Tau]\_1\%4\ \[Mu]\_\(0, 2\) + 
        8\ \[Theta]e\_1\ \[Tau]\_1\%4\ \[Mu]\_\(0, 2\) - 
        4\ \[Theta]e\_1\%2\ \[Tau]\_1\%4\ \[Mu]\_\(0, 2\) - 
        16\ \[Rho]\_1\ \[Tau]\_1\%4\ \[Mu]\_\(0, 2\) + 
        32\ \[Theta]e\_1\ \[Rho]\_1\ \[Tau]\_1\%4\ \[Mu]\_\(0, 2\) - 
        16\ \[Theta]e\_1\%2\ \[Rho]\_1\ \[Tau]\_1\%4\ \[Mu]\_\(0, 2\) + 
        16\ \[Rho]\_2\ \[Tau]\_1\%4\ \[Mu]\_\(0, 2\) - 
        32\ \[Theta]e\_1\ \[Rho]\_2\ \[Tau]\_1\%4\ \[Mu]\_\(0, 2\) + 
        16\ \[Theta]e\_1\%2\ \[Rho]\_2\ \[Tau]\_1\%4\ \[Mu]\_\(0, 2\) - 
        8\ \[Tau]\_1\%3\ \[Tau]\_2\ \[Mu]\_\(0, 2\) + 
        24\ \[Theta]e\_1\ \[Tau]\_1\%3\ \[Tau]\_2\ \[Mu]\_\(0, 2\) - 
        16\ \[Theta]e\_1\%2\ \[Tau]\_1\%3\ \[Tau]\_2\ \[Mu]\_\(0, 2\) - 
        8\ \[Rho]\_1\ \[Tau]\_1\%3\ \[Tau]\_2\ \[Mu]\_\(0, 2\) + 
        56\ \[Theta]e\_1\ \[Rho]\_1\ \[Tau]\_1\%3\ \[Tau]\_2\ \[Mu]\_\(0, 2\) \
- 48\ \[Theta]e\_1\%2\ \[Rho]\_1\ \[Tau]\_1\%3\ \[Tau]\_2\ \[Mu]\_\(0, 2\) + 
        8\ \[Rho]\_2\ \[Tau]\_1\%3\ \[Tau]\_2\ \[Mu]\_\(0, 2\) - 
        56\ \[Theta]e\_1\ \[Rho]\_2\ \[Tau]\_1\%3\ \[Tau]\_2\ \[Mu]\_\(0, 2\) \
+ 48\ \[Theta]e\_1\%2\ \[Rho]\_2\ \[Tau]\_1\%3\ \[Tau]\_2\ \[Mu]\_\(0, 2\) - 
        4\ \[Tau]\_1\%2\ \[Tau]\_2\%2\ \[Mu]\_\(0, 2\) + 
        24\ \[Theta]e\_1\ \[Tau]\_1\%2\ \[Tau]\_2\%2\ \[Mu]\_\(0, 2\) - 
        24\ \[Theta]e\_1\%2\ \[Tau]\_1\%2\ \[Tau]\_2\%2\ \[Mu]\_\(0, 2\) + 
        8\ \[Rho]\_1\ \[Tau]\_1\%2\ \[Tau]\_2\%2\ \[Mu]\_\(0, 2\) + 
        16\ \[Theta]e\_1\ \[Rho]\_1\ \[Tau]\_1\%2\ \[Tau]\_2\%2\ \[Mu]\_\(0, \
2\) - 48\ \[Theta]e\_1\%2\ \[Rho]\_1\ \[Tau]\_1\%2\ \[Tau]\_2\%2\ \[Mu]\_\(0, \
2\) - 8\ \[Rho]\_2\ \[Tau]\_1\%2\ \[Tau]\_2\%2\ \[Mu]\_\(0, 2\) - 
        16\ \[Theta]e\_1\ \[Rho]\_2\ \[Tau]\_1\%2\ \[Tau]\_2\%2\ \[Mu]\_\(0, \
2\) + 48\ \[Theta]e\_1\%2\ \[Rho]\_2\ \[Tau]\_1\%2\ \[Tau]\_2\%2\ \[Mu]\_\(0, \
2\) + 8\ \[Theta]e\_1\ \[Tau]\_1\ \[Tau]\_2\%3\ \[Mu]\_\(0, 2\) - 
        16\ \[Theta]e\_1\%2\ \[Tau]\_1\ \[Tau]\_2\%3\ \[Mu]\_\(0, 2\) - 
        8\ \[Theta]e\_1\ \[Rho]\_1\ \[Tau]\_1\ \[Tau]\_2\%3\ \[Mu]\_\(0, 2\) \
- 16\ \[Theta]e\_1\%2\ \[Rho]\_1\ \[Tau]\_1\ \[Tau]\_2\%3\ \[Mu]\_\(0, 2\) + 
        8\ \[Theta]e\_1\ \[Rho]\_2\ \[Tau]\_1\ \[Tau]\_2\%3\ \[Mu]\_\(0, 2\) \
+ 16\ \[Theta]e\_1\%2\ \[Rho]\_2\ \[Tau]\_1\ \[Tau]\_2\%3\ \[Mu]\_\(0, 2\) - 
        4\ \[Theta]e\_1\%2\ \[Tau]\_2\%4\ \[Mu]\_\(0, 2\) - 
        16\ \[Rho]\_1\%2\ \[Tau]\_1\%3\ \[Tau]\_2\ \[Mu]\_\(0, 2\)\ \
\[Mu]\_\(3, 0\)\%2 + 
        16\ \[Theta]e\_1\ \[Rho]\_1\%2\ \[Tau]\_1\%3\ \[Tau]\_2\ \[Mu]\_\(0, \
2\)\ \[Mu]\_\(3, 0\)\%2 + 
        32\ \[Rho]\_1\ \[Rho]\_2\ \[Tau]\_1\%3\ \[Tau]\_2\ \[Mu]\_\(0, 2\)\ \
\[Mu]\_\(3, 0\)\%2 - 
        32\ \[Theta]e\_1\ \[Rho]\_1\ \[Rho]\_2\ \[Tau]\_1\%3\ \[Tau]\_2\ \
\[Mu]\_\(0, 2\)\ \[Mu]\_\(3, 0\)\%2 - 
        16\ \[Rho]\_2\%2\ \[Tau]\_1\%3\ \[Tau]\_2\ \[Mu]\_\(0, 2\)\ \
\[Mu]\_\(3, 0\)\%2 + 
        16\ \[Theta]e\_1\ \[Rho]\_2\%2\ \[Tau]\_1\%3\ \[Tau]\_2\ \[Mu]\_\(0, \
2\)\ \[Mu]\_\(3, 0\)\%2 + 
        4\ \[Rho]\_1\%2\ \[Tau]\_1\%2\ \[Tau]\_2\%2\ \[Mu]\_\(0, 2\)\ \[Mu]\_\
\(3, 0\)\%2 + 
        16\ \[Theta]e\_1\ \[Rho]\_1\%2\ \[Tau]\_1\%2\ \[Tau]\_2\%2\ \
\[Mu]\_\(0, 2\)\ \[Mu]\_\(3, 0\)\%2 - 
        8\ \[Rho]\_1\ \[Rho]\_2\ \[Tau]\_1\%2\ \[Tau]\_2\%2\ \[Mu]\_\(0, 2\)\ \
\[Mu]\_\(3, 0\)\%2 - 
        32\ \[Theta]e\_1\ \[Rho]\_1\ \[Rho]\_2\ \[Tau]\_1\%2\ \[Tau]\_2\%2\ \
\[Mu]\_\(0, 2\)\ \[Mu]\_\(3, 0\)\%2 + 
        4\ \[Rho]\_2\%2\ \[Tau]\_1\%2\ \[Tau]\_2\%2\ \[Mu]\_\(0, 2\)\ \[Mu]\_\
\(3, 0\)\%2 + 
        16\ \[Theta]e\_1\ \[Rho]\_2\%2\ \[Tau]\_1\%2\ \[Tau]\_2\%2\ \
\[Mu]\_\(0, 2\)\ \[Mu]\_\(3, 0\)\%2 - 
        3\ \[Kappa]\_1\ \[Tau]\_1\%4\ \[Mu]\_\(0, 2\)\ \[Mu]\_\(4, 0\) + 
        4\ \[Theta]e\_1\ \[Kappa]\_1\ \[Tau]\_1\%4\ \[Mu]\_\(0, 2\)\ \
\[Mu]\_\(4, 0\) - 
        2\ \[Kappa]\_1\ \[Tau]\_1\%3\ \[Tau]\_2\ \[Mu]\_\(0, 2\)\ \[Mu]\_\(4, \
0\) + 8\ \[Theta]e\_1\ \[Kappa]\_1\ \[Tau]\_1\%3\ \[Tau]\_2\ \[Mu]\_\(0, 2\)\ \
\[Mu]\_\(4, 0\) - 
        4\ \[Kappa]\_2\ \[Tau]\_1\%3\ \[Tau]\_2\ \[Mu]\_\(0, 2\)\ \[Mu]\_\(4, \
0\) + 4\ \[Theta]e\_1\ \[Kappa]\_2\ \[Tau]\_1\%3\ \[Tau]\_2\ \[Mu]\_\(0, 2\)\ \
\[Mu]\_\(4, 0\) + \[Kappa]\_1\ \[Tau]\_1\%2\ \[Tau]\_2\%2\ \[Mu]\_\(0, 2\)\ \
\[Mu]\_\(4, 0\) + 
        4\ \[Theta]e\_1\ \[Kappa]\_1\ \[Tau]\_1\%2\ \[Tau]\_2\%2\ \[Mu]\_\(0, \
2\)\ \[Mu]\_\(4, 0\) - 
        4\ \[Kappa]\_2\ \[Tau]\_1\%2\ \[Tau]\_2\%2\ \[Mu]\_\(0, 2\)\ \
\[Mu]\_\(4, 0\) + 
        8\ \[Theta]e\_1\ \[Kappa]\_2\ \[Tau]\_1\%2\ \[Tau]\_2\%2\ \[Mu]\_\(0, \
2\)\ \[Mu]\_\(4, 0\) + 
        4\ \[Theta]e\_1\ \[Kappa]\_2\ \[Tau]\_1\ \[Tau]\_2\%3\ \[Mu]\_\(0, \
2\)\ \[Mu]\_\(4, 0\))\)\)\)], "Output"]
}, Open  ]],

Cell["\<\
We take the difference in the past two expressions to compute the impact of \
the new security.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(UtilDiff = \((Util4\  - \((Util4 /. {\ \[Mu]\_\(2, 1\) -> 0})\))\) // 
        Expand\)], "Input"],

Cell[BoxData[
    \(\(-\(\(2\ \[Rho]\_1\%2\ \[Tau]\_1\%2\ \[Tau]\_2\ \[Mu]\_\(2, 1\)\%2\)\/\
\(\((\[Tau]\_1 + \[Tau]\_2)\)\^6\ \[Mu]\_\(0, 2\)\)\)\) + \(2\ \[Theta]e\_1\ \
\[Rho]\_1\%2\ \[Tau]\_1\%2\ \[Tau]\_2\ \[Mu]\_\(2, 1\)\%2\)\/\(\((\[Tau]\_1 + \
\[Tau]\_2)\)\^6\ \[Mu]\_\(0, 2\)\) + \(4\ \[Rho]\_1\ \[Rho]\_2\ \[Tau]\_1\%2\ \
\[Tau]\_2\ \[Mu]\_\(2, 1\)\%2\)\/\(\((\[Tau]\_1 + \[Tau]\_2)\)\^6\ \
\[Mu]\_\(0, 2\)\) - \(4\ \[Theta]e\_1\ \[Rho]\_1\ \[Rho]\_2\ \[Tau]\_1\%2\ \
\[Tau]\_2\ \[Mu]\_\(2, 1\)\%2\)\/\(\((\[Tau]\_1 + \[Tau]\_2)\)\^6\ \
\[Mu]\_\(0, 2\)\) - \(2\ \[Rho]\_2\%2\ \[Tau]\_1\%2\ \[Tau]\_2\ \[Mu]\_\(2, 1\
\)\%2\)\/\(\((\[Tau]\_1 + \[Tau]\_2)\)\^6\ \[Mu]\_\(0, 2\)\) + \(2\ \[Theta]e\
\_1\ \[Rho]\_2\%2\ \[Tau]\_1\%2\ \[Tau]\_2\ \[Mu]\_\(2, 1\)\%2\)\/\(\((\[Tau]\
\_1 + \[Tau]\_2)\)\^6\ \[Mu]\_\(0, 2\)\) + \(\[Rho]\_1\%2\ \[Tau]\_1\ \
\[Tau]\_2\%2\ \[Mu]\_\(2, 1\)\%2\)\/\(2\ \((\[Tau]\_1 + \[Tau]\_2)\)\^6\ \
\[Mu]\_\(0, 2\)\) + \(2\ \[Theta]e\_1\ \[Rho]\_1\%2\ \[Tau]\_1\ \[Tau]\_2\%2\ \
\[Mu]\_\(2, 1\)\%2\)\/\(\((\[Tau]\_1 + \[Tau]\_2)\)\^6\ \[Mu]\_\(0, 2\)\) - \
\(\[Rho]\_1\ \[Rho]\_2\ \[Tau]\_1\ \[Tau]\_2\%2\ \[Mu]\_\(2, 1\)\%2\)\/\(\((\
\[Tau]\_1 + \[Tau]\_2)\)\^6\ \[Mu]\_\(0, 2\)\) - \(4\ \[Theta]e\_1\ \[Rho]\_1\
\ \[Rho]\_2\ \[Tau]\_1\ \[Tau]\_2\%2\ \[Mu]\_\(2, 1\)\%2\)\/\(\((\[Tau]\_1 + \
\[Tau]\_2)\)\^6\ \[Mu]\_\(0, 2\)\) + \(\[Rho]\_2\%2\ \[Tau]\_1\ \[Tau]\_2\%2\ \
\[Mu]\_\(2, 1\)\%2\)\/\(2\ \((\[Tau]\_1 + \[Tau]\_2)\)\^6\ \[Mu]\_\(0, 2\)\) \
+ \(2\ \[Theta]e\_1\ \[Rho]\_2\%2\ \[Tau]\_1\ \[Tau]\_2\%2\ \[Mu]\_\(2, \
1\)\%2\)\/\(\((\[Tau]\_1 + \[Tau]\_2)\)\^6\ \[Mu]\_\(0, 2\)\)\)], "Output"]
}, Open  ]],

Cell["\<\
This is a much simpler expression. We simplify the difference to arrive at \
the result in the paper.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(UtilDiff = Simplify[UtilDiff]\)], "Input"],

Cell[BoxData[
    \(\(\((\[Rho]\_1 - \[Rho]\_2)\)\^2\ \[Tau]\_1\ \[Tau]\_2\ \((4\ \((\(-1\) \
+ \[Theta]e\_1)\)\ \[Tau]\_1 + \((1 + 4\ \[Theta]e\_1)\)\ \[Tau]\_2)\)\ \[Mu]\
\_\(2, 1\)\%2\)\/\(2\ \((\[Tau]\_1 + \[Tau]\_2)\)\^6\ \[Mu]\_\(0, 2\)\)\)], \
"Output"]
}, Open  ]],

Cell[TextData[{
  "Use the identity ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\) + \[Theta]e\_1 - \[Theta]e\_2\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(UtilDiff = 
      UtilDiff /. {\(-1\) + \[Theta]e\_1 \[Rule] \(-\[Theta]e\_2\)}\)], \
"Input"],

Cell[BoxData[
    \(\(\((\[Rho]\_1 - \[Rho]\_2)\)\^2\ \[Tau]\_1\ \[Tau]\_2\ \((\(-4\)\ \
\[Theta]e\_2\ \[Tau]\_1 + \((1 + 4\ \[Theta]e\_1)\)\ \[Tau]\_2)\)\ \
\[Mu]\_\(2, 1\)\%2\)\/\(2\ \((\[Tau]\_1 + \[Tau]\_2)\)\^6\ \[Mu]\_\(0, \
2\)\)\)], "Output"]
}, Open  ]],

Cell["The expression in Theorem 12 is", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Thm12 = \(\(\(\((\[Rho]\_1 - \[Rho]\_2)\)\^2\)\(\ \)\(\[Tau]\_1\^2\)\(\ \
\)\(\[Tau]\_2\^2\)\(\ \ \)\)\/\(\(2\)\(\ \)\(\((\[Tau]\_1 + \[Tau]\_2)\)\^6\)\
\(\ \)\)\) \((4\ \((\[Theta]e\_1\/\(\(\ \)\(\[Tau]\_1\)\) - \[Theta]e\_2\/\
\[Tau]\_2)\) + 
            1\/\(\(\ \)\(\[Tau]\_1\)\))\) \(\(\ \ \)\(\[Mu]\_\(2, \
1\)\%2\)\)\/\(\(\ \)\(\[Mu]\_\(0, 2\)\)\)\)], "Input"],

Cell[BoxData[
    \(\(\((\[Rho]\_1 - \[Rho]\_2)\)\^2\ \[Tau]\_1\%2\ \((1\/\[Tau]\_1 + 4\ \
\((\[Theta]e\_1\/\[Tau]\_1 - \[Theta]e\_2\/\[Tau]\_2)\))\)\ \[Tau]\_2\%2\ \
\[Mu]\_\(2, 1\)\%2\)\/\(2\ \((\[Tau]\_1 + \[Tau]\_2)\)\^6\ \[Mu]\_\(0, \
2\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(UtilDiff - Thm12 // Simplify\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell["\<\
Therefore, our UtilDiff expression is equivalent to the one for utility \
change in Theorem 12.\
\>", "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1600}, {0, 1112}},
WindowSize->{886, 924},
WindowMargins->{{Automatic, 166}, {Automatic, 0}},
Visible->True,
PrintingCopies->1,
PrintingPageRange->{Automatic, Automatic},
InputAliases->{"notation"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftRightArrow]", " ",
           
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation>"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongRightArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "notation<"->RowBox[ {"Notation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], " ", "\[DoubleLongLeftArrow]", " ", 
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"]}], "]"}], 
    "symb"->RowBox[ {"Symbolize", "[", 
        TagBox[ 
        "\[Placeholder]", NotationBoxTag, TagStyle -> 
          "NotationTemplateStyle"], "]"}], 
    "infixnotation"->RowBox[ {"InfixNotation", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "addia"->RowBox[ {"AddInputAlias", "[", 
        RowBox[ {
          TagBox[ 
          "\[Placeholder]", NotationBoxTag, TagStyle -> 
            "NotationTemplateStyle"], ",", "\[Placeholder]"}], "]"}], 
    "pattwraper"->TagBox[ 
      "\[Placeholder]", NotationPatternTag, TagStyle -> 
        "NotationPatternWrapperStyle"], 
    "madeboxeswraper"->TagBox[ 
      "\[Placeholder]", NotationMadeBoxesTag, TagStyle -> 
        "NotationMadeBoxesWrapperStyle"]},
FontFamily->"Times New Roman",
Magnification->1.25,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of all cells in \
a given style.  Make modifications to any definition using commands in the \
Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{12, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{24, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->12],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{8, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->8],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    LineSpacing->{1, 0},
    FontSize->44],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    FontSize->20],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {12, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    FontSize->14],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->16,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}},
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubsection",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-.35999999999999999, \
-.10000000000000001}, {0, 0}}, BoxBaselineShift -> -.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-.074999999999999997, \
-.085000000000000006}, {0, 0}}, BoxBaselineShift -> .5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    DefaultNewInlineCellStyle->"None",
    Hyphenation->True,
    LineSpacing->{1, 3},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->0.5,
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names. \
Some attributes for these styles are actually set in FormatType Styles (in \
the last section of this stylesheet). \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}},
    FontSize->11],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9]
  }, Closed]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}},
    FontSize->11],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontSize->11,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->7,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}},
    FontSize->11],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageMargins->{{38, Inherited}, {Inherited, 0}},
    Magnification->0.6],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    Magnification->0.8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a cell \
exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Printout"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "EnhancedPrintout"],
    StyleMenuListing->None,
    FontFamily->"Futura",
    FontSize->7,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    ScriptLevel->1,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Program", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1},
    FontSize->11],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Hyperlink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["MainBookLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["AddOnsLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["RefGuideLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["GettingStartedLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["OtherInformationLink", "Condensed"],
    FontSize->11],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard ButtonFunctions, for use \
in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder objects in \
palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Placeholder->True,
    StyleMenuListing->None,
    FontSlant->"Italic",
    FontColor->RGBColor[0.890623, 0.864698, 0.384756],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PrimaryPlaceholder"],
    StyleMenuListing->None,
    DrawHighlighted->True,
    FontSlant->"Italic",
    Background->RGBColor[0.912505, 0.891798, 0.507774],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["PrimaryPlaceholder", "Presentation"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Condensed"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles of most \
cells.  If a cell's FormatType matches the name of one of the styles defined \
below, then that style is applied between the cell's style and its own \
options. This is particularly true of Input and Output.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    Hyphenation->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    InputAutoReplacements->{},
    AllowInlineCells->False,
    Hyphenation->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{0.6, 1},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an inline cell \
within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Automatic Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are used to affect the display of certain \
types of objects in typeset expressions.  For example, \"UnmatchedBracket\" \
style defines how unmatched bracket, curly bracket, and parenthesis \
characters are displayed (typically by coloring them to make them stand out).\
\
\>", "Text"],
  
  Cell[StyleData["UnmatchedBracket"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.760006, 0.330007, 0.8]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Notation Package Styles", "Section",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell["\<\
The cells below define certain styles needed by the Notation package. These \
styles serve to make visible otherwise invisible tagboxes.\
\>", "Text",
    GeneratedCell->True,
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationTemplateStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 1, 0.850004],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationPatternWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[1, 0.900008, 0.979995],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"],
  
  Cell[StyleData["NotationMadeBoxesWrapperStyle"],
    GeneratedCell->True,
    StyleMenuListing->None,
    Background->RGBColor[0.900008, 0.889998, 1],
    TagBoxOptions->{SyntaxForm->"symbol"},
    CellTags->"NotationPackage"]
  }, Closed]]
  }]
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 183, 6, 295, "Title"],
Cell[1925, 59, 212, 6, 38, "Text"],
Cell[2140, 67, 70, 0, 38, "Text"],
Cell[2213, 69, 53, 1, 35, "Input"],

Cell[CellGroupData[{
Cell[2291, 74, 36, 0, 66, "Section"],

Cell[CellGroupData[{
Cell[2352, 78, 36, 0, 57, "Subsection"],
Cell[2391, 80, 946, 27, 122, "Text"],
Cell[3340, 109, 88, 2, 35, "Input"],
Cell[3431, 113, 568, 19, 59, "Text"],
Cell[4002, 134, 114, 2, 35, "Input"],
Cell[4119, 138, 817, 33, 63, "Text"],
Cell[4939, 173, 182, 4, 36, "Input"],
Cell[5124, 179, 524, 14, 80, "Text"],
Cell[5651, 195, 1199, 42, 82, "Text"],
Cell[6853, 239, 90, 1, 35, "Input"],

Cell[CellGroupData[{
Cell[6968, 244, 873, 21, 98, "Input"],
Cell[7844, 267, 359, 6, 35, "Output"]
}, Open  ]],
Cell[8218, 276, 689, 18, 80, "Text"],

Cell[CellGroupData[{
Cell[8932, 298, 357, 7, 98, "Input"],
Cell[9292, 307, 443, 9, 35, "Output"],
Cell[9738, 318, 458, 9, 35, "Output"],
Cell[10199, 329, 529, 11, 35, "Output"],
Cell[10731, 342, 544, 11, 35, "Output"]
}, Open  ]],
Cell[11290, 356, 310, 7, 59, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11637, 368, 66, 0, 57, "Subsection"],
Cell[11706, 370, 1376, 40, 143, "Text"],

Cell[CellGroupData[{
Cell[13107, 414, 366, 6, 56, "Input"],
Cell[13476, 422, 157, 2, 36, "Output"],
Cell[13636, 426, 154, 3, 36, "Output"]
}, Open  ]],
Cell[13805, 432, 411, 15, 59, "Text"],
Cell[14219, 449, 120, 2, 35, "Input"],
Cell[14342, 453, 257, 11, 38, "Text"],
Cell[14602, 466, 122, 2, 35, "Input"],
Cell[14727, 470, 66, 0, 38, "Text"],

Cell[CellGroupData[{
Cell[14818, 474, 108, 2, 35, "Input"],
Cell[14929, 478, 403, 6, 58, "Output"]
}, Open  ]],
Cell[15347, 487, 545, 14, 80, "Text"],

Cell[CellGroupData[{
Cell[15917, 505, 124, 3, 35, "Input"],
Cell[16044, 510, 1159, 18, 102, "Output"]
}, Open  ]],
Cell[17218, 531, 186, 5, 38, "Text"],

Cell[CellGroupData[{
Cell[17429, 540, 1007, 28, 49, "Input"],
Cell[18439, 570, 188, 3, 49, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[18688, 580, 53, 0, 66, "Section"],
Cell[18744, 582, 299, 7, 38, "Text"],
Cell[19046, 591, 1076, 20, 119, "Input"],
Cell[20125, 613, 176, 5, 38, "Text"],

Cell[CellGroupData[{
Cell[20326, 622, 209, 3, 56, "Input"],
Cell[20538, 627, 3092, 68, 114, "Output"]
}, Open  ]],
Cell[23645, 698, 303, 11, 38, "Text"],

Cell[CellGroupData[{
Cell[23973, 713, 178, 4, 56, "Input"],
Cell[24154, 719, 3407, 76, 114, "Output"]
}, Open  ]],
Cell[27576, 798, 135, 5, 38, "Text"],

Cell[CellGroupData[{
Cell[27736, 807, 72, 1, 35, "Input"],
Cell[27811, 810, 936, 22, 36, "Output"]
}, Open  ]],
Cell[28762, 835, 236, 8, 38, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29035, 848, 61, 0, 66, "Section"],
Cell[29099, 850, 211, 4, 59, "Text"],

Cell[CellGroupData[{
Cell[29335, 858, 129, 2, 35, "Input"],
Cell[29467, 862, 110, 2, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29614, 869, 148, 2, 35, "Input"],
Cell[29765, 873, 132, 2, 35, "Output"]
}, Open  ]],
Cell[29912, 878, 261, 5, 59, "Text"],

Cell[CellGroupData[{
Cell[30198, 887, 290, 4, 98, "Input"],
Cell[30491, 893, 535, 9, 35, "Output"],
Cell[31029, 904, 623, 10, 56, "Output"],
Cell[31655, 916, 557, 10, 56, "Output"],
Cell[32215, 928, 651, 11, 56, "Output"]
}, Open  ]],
Cell[32881, 942, 258, 5, 59, "Text"],
Cell[33142, 949, 229, 6, 59, "Text"],

Cell[CellGroupData[{
Cell[33396, 959, 123, 2, 36, "Input"],
Cell[33522, 963, 290, 8, 40, "Output"]
}, Open  ]],
Cell[33827, 974, 435, 14, 59, "Text"],

Cell[CellGroupData[{
Cell[34287, 992, 263, 4, 52, "Input"],
Cell[34553, 998, 239, 4, 54, "Output"]
}, Open  ]],
Cell[34807, 1005, 387, 12, 59, "Text"],
Cell[35197, 1019, 194, 3, 36, "Input"],
Cell[35394, 1024, 253, 5, 59, "Text"],
Cell[35650, 1031, 726, 12, 182, "Input"],
Cell[36379, 1045, 227, 4, 59, "Text"],
Cell[36609, 1051, 246, 4, 98, "Input"],
Cell[36858, 1057, 267, 5, 59, "Text"],
Cell[37128, 1064, 306, 4, 98, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37471, 1073, 61, 0, 66, "Section"],

Cell[CellGroupData[{
Cell[37557, 1077, 33, 0, 57, "Subsection"],
Cell[37593, 1079, 213, 6, 38, "Text"],

Cell[CellGroupData[{
Cell[37831, 1089, 114, 2, 35, "Input"],
Cell[37948, 1093, 46, 1, 35, "Output"]
}, Open  ]],
Cell[38009, 1097, 210, 4, 59, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[38256, 1106, 33, 0, 57, "Subsection"],
Cell[38292, 1108, 241, 4, 59, "Text"],

Cell[CellGroupData[{
Cell[38558, 1116, 274, 4, 98, "Input"],
Cell[38835, 1122, 123, 2, 35, "Output"],
Cell[38961, 1126, 187, 3, 35, "Output"],
Cell[39151, 1131, 186, 3, 36, "Output"],
Cell[39340, 1136, 270, 4, 36, "Output"]
}, Open  ]],
Cell[39625, 1143, 52, 0, 38, "Text"],

Cell[CellGroupData[{
Cell[39702, 1147, 251, 4, 35, "Input"],
Cell[39956, 1153, 639, 12, 93, "Output"]
}, Open  ]],
Cell[40610, 1168, 85, 2, 38, "Text"],

Cell[CellGroupData[{
Cell[40720, 1174, 60, 1, 35, "Input"],
Cell[40783, 1177, 562, 10, 93, "Output"]
}, Open  ]],
Cell[41360, 1190, 594, 14, 80, "Text"],

Cell[CellGroupData[{
Cell[41979, 1208, 266, 5, 35, "Input"],
Cell[42248, 1215, 180, 3, 35, "Output"]
}, Open  ]],
Cell[42443, 1221, 68, 0, 38, "Text"],

Cell[CellGroupData[{
Cell[42536, 1225, 60, 1, 35, "Input"],
Cell[42599, 1228, 421, 8, 93, "Output"]
}, Open  ]],
Cell[43035, 1239, 277, 8, 59, "Text"],

Cell[CellGroupData[{
Cell[43337, 1251, 65, 1, 35, "Input"],
Cell[43405, 1254, 471, 8, 66, "Output"]
}, Open  ]],
Cell[43891, 1265, 318, 6, 80, "Text"],

Cell[CellGroupData[{
Cell[44234, 1275, 62, 1, 35, "Input"],
Cell[44299, 1278, 249, 3, 52, "Output"]
}, Open  ]],
Cell[44563, 1284, 397, 6, 80, "Text"],
Cell[44963, 1292, 1073, 28, 132, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[46073, 1325, 33, 0, 57, "Subsection"],
Cell[46109, 1327, 348, 10, 59, "Text"],
Cell[46460, 1339, 306, 4, 98, "Input"],
Cell[46769, 1345, 65, 0, 38, "Text"],

Cell[CellGroupData[{
Cell[46859, 1349, 36, 1, 35, "Input"],
Cell[46898, 1352, 1082, 23, 106, "Output"]
}, Open  ]],
Cell[47995, 1378, 528, 16, 59, "Text"],
Cell[48526, 1396, 286, 5, 35, "Input"],
Cell[48815, 1403, 436, 15, 59, "Text"],
Cell[49254, 1420, 62, 1, 35, "Input"],
Cell[49319, 1423, 486, 11, 80, "Text"],
Cell[49808, 1436, 89, 2, 38, "Text"],

Cell[CellGroupData[{
Cell[49922, 1442, 118, 2, 56, "Input"],
Cell[50043, 1446, 6266, 166, 186, "Output"]
}, Open  ]],
Cell[56324, 1615, 93, 2, 38, "Text"],

Cell[CellGroupData[{
Cell[56442, 1621, 129, 2, 56, "Input"],
Cell[56574, 1625, 3598, 99, 170, "Output"]
}, Open  ]],
Cell[60187, 1727, 230, 7, 38, "Text"],
Cell[60420, 1736, 72, 0, 38, "Text"],

Cell[CellGroupData[{
Cell[60517, 1740, 59, 1, 35, "Input"],
Cell[60579, 1743, 1116, 25, 96, "Output"]
}, Open  ]],
Cell[61710, 1771, 486, 14, 59, "Text"],

Cell[CellGroupData[{
Cell[62221, 1789, 85, 1, 51, "Subsubsection"],
Cell[62309, 1792, 475, 14, 59, "Text"],
Cell[62787, 1808, 204, 7, 38, "Text"],

Cell[CellGroupData[{
Cell[63016, 1819, 85, 1, 35, "Input"],
Cell[63104, 1822, 217, 3, 55, "Output"]
}, Open  ]],
Cell[63336, 1828, 344, 6, 80, "Text"],

Cell[CellGroupData[{
Cell[63705, 1838, 70, 1, 35, "Input"],
Cell[63778, 1841, 138, 2, 53, "Output"]
}, Open  ]],
Cell[63931, 1846, 62, 0, 38, "Text"],

Cell[CellGroupData[{
Cell[64018, 1850, 85, 1, 35, "Input"],
Cell[64106, 1853, 176, 3, 55, "Output"]
}, Open  ]],
Cell[64297, 1859, 58, 0, 38, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[64404, 1865, 33, 0, 57, "Subsection"],
Cell[64440, 1867, 261, 7, 38, "Text"],
Cell[64704, 1876, 718, 12, 98, "Input"],
Cell[65425, 1890, 65, 0, 38, "Text"],

Cell[CellGroupData[{
Cell[65515, 1894, 36, 1, 35, "Input"],
Cell[65554, 1897, 1449, 30, 108, "Output"]
}, Open  ]],
Cell[67018, 1930, 48, 0, 38, "Text"],
Cell[67069, 1932, 302, 5, 56, "Input"],

Cell[CellGroupData[{
Cell[67396, 1941, 101, 2, 56, "Input"],
Cell[67500, 1945, 5769, 95, 509, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[73306, 2045, 54, 0, 51, "Subsubsection"],
Cell[73363, 2047, 97, 2, 38, "Text"],

Cell[CellGroupData[{
Cell[73485, 2053, 111, 2, 35, "Input"],
Cell[73599, 2057, 1914, 25, 201, "Output"]
}, Open  ]],
Cell[75528, 2085, 41, 0, 38, "Text"],

Cell[CellGroupData[{
Cell[75594, 2089, 113, 2, 36, "Input"],
Cell[75710, 2093, 77, 1, 35, "Output"]
}, Open  ]],
Cell[75802, 2097, 64, 0, 38, "Text"],

Cell[CellGroupData[{
Cell[75891, 2101, 113, 2, 35, "Input"],
Cell[76007, 2105, 451, 9, 49, "Output"]
}, Open  ]],
Cell[76473, 2117, 181, 5, 38, "Text"],

Cell[CellGroupData[{
Cell[76679, 2126, 230, 4, 56, "Input"],
Cell[76912, 2132, 1220, 18, 150, "Output"]
}, Open  ]],
Cell[78147, 2153, 416, 12, 59, "Text"],

Cell[CellGroupData[{
Cell[78588, 2169, 107, 2, 35, "Input"],
Cell[78698, 2173, 950, 14, 105, "Output"]
}, Open  ]],
Cell[79663, 2190, 183, 6, 38, "Text"],

Cell[CellGroupData[{
Cell[79871, 2200, 111, 2, 35, "Input"],
Cell[79985, 2204, 185, 3, 59, "Output"]
}, Open  ]],
Cell[80185, 2210, 49, 0, 38, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[80283, 2216, 33, 0, 57, "Subsection"],
Cell[80319, 2218, 326, 8, 59, "Text"],
Cell[80648, 2228, 778, 16, 98, "Input"],
Cell[81429, 2246, 59, 0, 38, "Text"],

Cell[CellGroupData[{
Cell[81513, 2250, 48, 1, 35, "Input"],
Cell[81564, 2253, 10777, 188, 301, "Output"]
}, Open  ]],
Cell[92356, 2444, 155, 3, 38, "Text"],
Cell[92514, 2449, 318, 5, 77, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[92881, 2460, 37, 0, 80, "Subtitle"],
Cell[92921, 2462, 212, 5, 38, "Text"],

Cell[CellGroupData[{
Cell[93158, 2471, 65, 2, 67, "Section"],
Cell[93226, 2475, 323, 11, 38, "Text"],

Cell[CellGroupData[{
Cell[93574, 2490, 52, 1, 35, "Input"],
Cell[93629, 2493, 279, 5, 35, "Output"]
}, Open  ]],
Cell[93923, 2501, 285, 5, 59, "Text"],

Cell[CellGroupData[{
Cell[94233, 2510, 83, 1, 35, "Input"],
Cell[94319, 2513, 394, 7, 35, "Output"]
}, Open  ]],
Cell[94728, 2523, 134, 3, 38, "Text"],
Cell[94865, 2528, 110, 2, 35, "Input"],
Cell[94978, 2532, 189, 8, 38, "Text"],
Cell[95170, 2542, 63, 1, 35, "Input"],
Cell[95236, 2545, 236, 8, 38, "Text"],
Cell[95475, 2555, 67, 1, 35, "Input"],
Cell[95545, 2558, 139, 3, 38, "Text"],
Cell[95687, 2563, 130, 2, 35, "Input"],
Cell[95820, 2567, 73, 2, 38, "Text"],
Cell[95896, 2571, 70, 1, 35, "Input"],
Cell[95969, 2574, 114, 3, 38, "Text"],
Cell[96086, 2579, 104, 2, 35, "Input"],
Cell[96193, 2583, 207, 7, 38, "Text"],

Cell[CellGroupData[{
Cell[96425, 2594, 88, 1, 35, "Input"],
Cell[96516, 2597, 457, 7, 94, "Output"]
}, Open  ]],
Cell[96988, 2607, 421, 12, 59, "Text"],

Cell[CellGroupData[{
Cell[97434, 2623, 50, 0, 57, "Subsection"],
Cell[97487, 2625, 377, 12, 59, "Text"],
Cell[97867, 2639, 107, 3, 38, "Text"],

Cell[CellGroupData[{
Cell[97999, 2646, 82, 1, 35, "Input"],
Cell[98084, 2649, 5715, 93, 416, "Output"]
}, Open  ]],
Cell[103814, 2745, 636, 15, 101, "Text"],

Cell[CellGroupData[{
Cell[104475, 2764, 72, 1, 35, "Input"],
Cell[104550, 2767, 4728, 77, 369, "Output"]
}, Open  ]],
Cell[109293, 2847, 119, 3, 38, "Text"],

Cell[CellGroupData[{
Cell[109437, 2854, 118, 2, 35, "Input"],
Cell[109558, 2858, 1633, 21, 157, "Output"]
}, Open  ]],
Cell[111206, 2882, 125, 3, 38, "Text"],

Cell[CellGroupData[{
Cell[111356, 2889, 62, 1, 35, "Input"],
Cell[111421, 2892, 260, 4, 59, "Output"]
}, Open  ]],
Cell[111696, 2899, 139, 5, 38, "Text"],

Cell[CellGroupData[{
Cell[111860, 2908, 114, 3, 35, "Input"],
Cell[111977, 2913, 250, 4, 59, "Output"]
}, Open  ]],
Cell[112242, 2920, 47, 0, 38, "Text"],

Cell[CellGroupData[{
Cell[112314, 2924, 387, 6, 59, "Input"],
Cell[112704, 2932, 259, 4, 69, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[113000, 2941, 61, 1, 35, "Input"],
Cell[113064, 2944, 35, 1, 35, "Output"]
}, Open  ]],
Cell[113114, 2948, 119, 3, 38, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

